Index: announcer.py
===================================================================
--- announcer.py	(revision 1038)
+++ announcer.py	(working copy)
@@ -30,7 +30,7 @@
       if os.path.isfile(os.path.join(path,"themes","dj",name,"djtheme.cfg")):
         filename = os.path.join(path, "themes", "dj", name)
     if filename == None:
-      raise SystemExit("E: Cannot load announcer theme '%s'." % name)
+      raise SystemExit(_("E: Cannot load announcer theme '%s'.") % name)
 
     fi = file(os.path.join(filename, "djtheme.cfg"), "r")
     sec = ""
Index: judge.py
===================================================================
--- judge.py	(revision 1038)
+++ judge.py	(working copy)
@@ -141,7 +141,7 @@
 judges = [TimeJudge, BeatJudge]
 judge_opt = [
   (0, "Time",
-   "Judging is based on how many seconds you are from the correct time."),
+   _("Judging is based on how many seconds you are from the correct time.")),
   (1, "Beat",
-   "Judging is based on how many beats you are from the correct time."),
+   _("Judging is based on how many beats you are from the correct time.")),
   ]
Index: util.py
===================================================================
--- util.py	(revision 1038)
+++ util.py	(working copy)
@@ -2,17 +2,29 @@
 import os
 import string
 
+from i18n import *
+
 # This is the standard order to present difficulties in.
 # DDR (USA home version) calls "beginner" "standard". Ignore that.
 # Beginner, light, basic, another, standard, trick, maniac, heavy, challenge,
 # and oni are from DDR. Smaniac is from DWI; s-maniac is a very common typo.
 # Hardcore is from pydance. Para and expert are from PPP. Easy, and hard are
 # from TM and PIU; medium is from TM; crazy is from PIU.
-DIFFICULTY_LIST = ["BEGINNER", "EASY", "LIGHT", "BASIC", "PARA", "ANOTHER",
-                   "NORMAL", "MEDIUM", "STANDARD", "TRICK", "DOUBLE", "HARD",
-                   "MANIAC", "HEAVY", "HARDCORE", "CHALLENGE", "ONI",
-                   "SMANIAC", "S-MANIAC", "CRAZY", "EXPERT"]
 
+#We need a dummy difficulty list to include it to .pot file
+DIFFICULTY_LIST_I18N = [_("BEGINNER"),_("EASY"),_("LIGHT"),_("BASIC"),_("PARA"),
+                   _("ANOTHER"),_("NORMAL"),_("MEDIUM"),_("STANDARD"),
+                   _("TRICK"),_("DOUBLE"),_("HARD"),_("MANIAC"),_("HEAVY"),
+                   _("HARDCORE"),_("CHALLENGE"),_("ONI"),_("SMANIAC"),
+                   _("S-MANIAC"),_("CRAZY"),_("EXPERT")]
+
+
+DIFFICULTY_LIST = ["BEGINNER","EASY","LIGHT","BASIC","PARA",
+                   "ANOTHER","NORMAL","MEDIUM","STANDARD",
+                   "TRICK","DOUBLE","HARD","MANIAC","HEAVY",
+                   "HARDCORE","CHALLENGE","ONI","SMANIAC",
+                   "S-MANIAC","CRAZY","EXPERT"]
+
 def difficulty_sort(a, b):
   if a in DIFFICULTY_LIST and b in DIFFICULTY_LIST:
     return cmp(DIFFICULTY_LIST.index(a), DIFFICULTY_LIST.index(b))
Index: lifebars.py
===================================================================
--- lifebars.py	(revision 1038)
+++ lifebars.py	(working copy)
@@ -5,6 +5,8 @@
 from listener import Listener
 from constants import *
 
+from i18n import *
+
 LIVING, FAILED, WON = range(3)
 
 # The base lifebar class from which most other ones inherit.
@@ -18,7 +20,7 @@
     self.record = []
     self.last_record_update = 0
 
-    self.failtext = fontfx.embfade("FAILED", 28, 3, [80, 32], [224, 32, 32])
+    self.failtext = fontfx.embfade(_("FAILED"), 28, 3, [80, 32], [224, 32, 32])
     self.failtext.set_colorkey(self.failtext.get_at([0, 0]), RLEACCEL)
 
     self.rect = self.image.get_rect()
@@ -213,9 +215,9 @@
 bars = [LifeBarDisp, OniLifeBarDisp, DropLifeBarDisp, MediocreLifeBarDisp,
         TugLifeBarDisp, GreatAttack]
 
-lifebar_opt = [(0, "Normal", ""),
-               (1, "Battery", "A few points of life, increasing each song."),
-               (2, "Power Drop", "Like normal, but never goes back up."),
-               (3, "Mediocre", "Fail if you do too poorly or too well."),
-               (4, "Tug of War", "Fight with the other player for life."),
-               (5, "Great Attack", "Only greats make the bar go up.")]
+lifebar_opt = [(0, _("Normal"), ""),
+               (1, _("Battery"), _("A few points of life, increasing each song.")),
+               (2, _("Power Drop"), _("Like normal, but never goes back up.")),
+               (3, _("Mediocre"), _("Fail if you do too poorly or too well.")),
+               (4, _("Tug of War"), _("Fight with the other player for life.")),
+               (5, _("Great Attack"), _("Only greats make the bar go up."))]
Index: constants.py
===================================================================
--- constants.py	(revision 1038)
+++ constants.py	(working copy)
@@ -5,6 +5,9 @@
 import sys
 import os
 import locale
+
+from i18n import *
+
 VERSION = "1.0.3"
 
 try: locale.setlocale(locale.LC_ALL, '')
Index: Makefile.posix
===================================================================
--- Makefile.posix	(revision 1038)
+++ Makefile.posix	(working copy)
@@ -2,6 +2,8 @@
 
 PREFIX ?= /usr/local
 
+LOCALESDIR=/usr/share/locale
+
 all:
 
 include Makefile.general
@@ -10,6 +12,7 @@
 	install -m 644 $(ALLMODS) $(DESTDIR)$(PREFIX)/share/games/pydance
 	install -m 755 pydance.py $(DESTDIR)$(PREFIX)/share/games/pydance
 	ln -sf ../share/games/pydance/pydance.py $(DESTDIR)$(PREFIX)/games/pydance
+	@(cd po/ && env LOCALESDIR=$(LOCALESDIR) $(MAKE) $@)
 
 install-core:
 	install -d $(DESTDIR)$(PREFIX)/bin $(DESTDIR)$(PREFIX)/games $(DESTDIR)$(PREFIX)/share/games/pydance
Index: options.py
===================================================================
--- options.py	(revision 1038)
+++ options.py	(working copy)
@@ -15,8 +15,10 @@
 from constants import *
 from interface import *
 
-ON_OFF = [(0, "Off", ""), (1, "On", "")]
+from i18n import *
 
+ON_OFF = [(0, _("Off"), ""), (1, _("On"), "")]
+
 # Description gets assigned 2 both times.
 PP, NAME, DESCRIPTION, VALUES = range(4)
 VALUE, NAME, DESCRIPTION = range(3)
@@ -29,138 +31,138 @@
   # 3. A list of 3-tuples (a, b, c) where a is the value of the option.
   #    b is the string to display for that value, and c is a string
   #    describing the value.
-  "speed": (True, "Speed",
-            "Adjust the speed at which the arrows scroll across the screen.",
+  "speed": (True, _("Speed"),
+            _("Adjust the speed at which the arrows scroll across the screen."),
             zip([0.25, 0.33, 0.5, 0.75, 1, 1.5, 2, 2.5, 3, 4, 5, 8, -200, -300, -400, -500, -600, -700, -800],
                 ["0.25x", "0.33x", "0.50x", "0.75x", "1.0x", "1.5x", "2.0x", "2.5x",
                  "3.0x", "4.0x", "5.0x", "8.0x", "200bpm", "300bpm", "400bpm", "500bpm", "600bpm", "700bpm", "800bpm"],
-                [""] * 12 + ["Arrows scroll at 200bpm.", "Arrows scroll at 300bpm.", "Arrows scroll at 400bpm.", "Arrows scroll at 500bpm.", "Arrows scroll at 600bpm.", "Arrows scroll at 700bpm.", "Arrows scroll at 800bpm."])
+                [""] * 12 + [_("Arrows scroll at 200bpm."), _("Arrows scroll at 300bpm."), _("Arrows scroll at 400bpm."), _("Arrows scroll at 500bpm."), _("Arrows scroll at 600bpm."), _("Arrows scroll at 700bpm."), _("Arrows scroll at 800bpm.")])
             ),
-  "transform": (True, "Transform",
-                "Change the step patterns for the song.",
+  "transform": (True, _("Transform"),
+                _("Change the step patterns for the song."),
                 zip([0, 1, 2, 3, -1, -2],
-                    ["Normal", "Mirror", "Left", "Right", "Shuffle", "Random"],
-                    ["", "Rotate the steps 180 degrees.",
-                     "Rotate the steps 90 degrees to the left.",
-                     "Rotate the steps 90 degrees to the right.",
-                     "Swap all arrows from one direction to another.",
-                     "Use totally random directions."])
+                    [_("Normal"), _("Mirror"), _("Left"), _("Right"), _("Shuffle"), _("Random")],
+                    ["", _("Rotate the steps 180 degrees."),
+                     _("Rotate the steps 90 degrees to the left."),
+                     _("Rotate the steps 90 degrees to the right."),
+                     _("Swap all arrows from one direction to another."),
+                     _("Use totally random directions.")])
                 ),
-  "size": (True, "Add/Remove Steps",
-           "Add or remove arrows from step patterns.",
+  "size": (True, _("Add/Remove Steps"),
+           _("Add or remove arrows from step patterns."),
            zip([1, 2, 0, 3, 4, 5],
-               ["Tiny", "Little", "Normal", "Big", "Quick", "Skippy"],
-               ["Only dance to on-beat notes.",
-                "Only dance to on-beat and half-beat notes.",
-                "", "Add half-beat steps between on-beat ones.",
-                "Add steps between half-beat ones.",
-                "Add gallops between on-beat steps."])
+               [_("Tiny"), _("Little"), _("Normal"), _("Big"), _("Quick"), _("Skippy")],
+               [_("Only dance to on-beat notes."),
+                _("Only dance to on-beat and half-beat notes."),
+                "", _("Add half-beat steps between on-beat ones."),
+                _("Add steps between half-beat ones."),
+                _("Add gallops between on-beat steps.")])
            ),
-  "fade": (True, "Fade",
-           "Fade arrows in or out while they scroll.",
+  "fade": (True, _("Fade"),
+           _("Fade arrows in or out while they scroll."),
            zip([0, 1, 2, 3, 4, 5],
-               ["Normal", "Sudden", "Hidden", "Peek", "Cycle", "Stealth"],
-               ["", "Only display arrows near the top.",
-                "Only display arrows near the bottom.",
-                "Only display arrows near the middle.",
-                "Blink arrows in and out.",
-                "No arrows are displayed."])
+               [_("Normal"), _("Sudden"), _("Hidden"), _("Peek"), _("Cycle"), _("Stealth")],
+               ["", _("Only display arrows near the top."),
+                _("Only display arrows near the bottom."),
+                _("Only display arrows near the middle."),
+                _("Blink arrows in and out."),
+                _("No arrows are displayed.")])
            ),
-  "accel": (True, "Acceleration",
-            "Accelerate or decelerate arrows.",
+  "accel": (True, _("Acceleration"),
+            _("Accelerate or decelerate arrows."),
             zip([2, 0, 1],
-                ["Brake", "Normal", "Boost"],
-                ["Decelerate near the top", "", "Accelerate near the top."])
+                [_("Brake"), _("Normal"), _("Boost")],
+                [_("Decelerate near the top"), "", _("Accelerate near the top.")])
             ),
-  "scale": (True, "Size",
-            "Change arrow sizes.",
+  "scale": (True, _("Size"),
+            _("Change arrow sizes."),
             zip([0, 1, 2],
-                ["Shrink", "Normal", "Grow"],
-                ["Smaller arrows near the top.", "",
-                 "Smaller arrows near the bottom."])
+                [_("Shrink"), _("Normal"), _("Grow")],
+                [_("Smaller arrows near the top."), "",
+                 _("Smaller arrows near the bottom.")])
             ),
-  "scrollstyle": (True, "Direction",
-                  "Change the direction arrows scroll.",
+  "scrollstyle": (True, _("Direction"),
+                  _("Change the direction arrows scroll."),
                   zip([0, 1, 2],
-                      ["Normal", "Reverse", "Center"],
-                      ["Arrows go from bottom to top.",
-                       "Arrows go from top to bottom.",
-                       "Arrows go from the top and bottom to the center."])
+                      [_("Normal"), _("Reverse"), _("Center")],
+                      [_("Arrows go from bottom to top."),
+                       _("Arrows go from top to bottom."),
+                       _("Arrows go from the top and bottom to the center.")])
                   ),
-  "jumps": (True, "Jumps",
-            "Turn jumps off, or add more.",
+  "jumps": (True, _("Jumps"),
+            _("Turn jumps off, or add more."),
             zip([0, 1, 2],
-                ["Off", "On", "Wide"],
-                ["Remove jumps from the song.", "",
-                 "Add jumps on every on-beat step."])
+                [_("Off"), _("On"), _("Wide")],
+                [_("Remove jumps from the song."), "",
+                 _("Add jumps on every on-beat step.")])
             ),
-  "spin": (True, "Spin",
-           "Rotate arrows as they go up the screen.",
+  "spin": (True, _("Spin"),
+           _("Rotate arrows as they go up the screen."),
            ON_OFF),
-  "colortype": (True, "Colors",
-                "Use colors of arrows to indicate the beat.",
+  "colortype": (True, _("Colors"),
+                _("Use colors of arrows to indicate the beat."),
                 zip([1, 4],
-                    ["Flat", "Normal"],
-                    ["All arrows are the same.",
-                     "Different arrows have different colors."])
+                    [_("Flat"), _("Normal")],
+                    [_("All arrows are the same."),
+                     _("Different arrows have different colors.")])
                 ),
-  "dark": (True, "Dark",
-           "Don't display the top arrows.",
+  "dark": (True, _("Dark"),
+           _("Don't display the top arrows."),
            ON_OFF),
-  "holds": (True, "Holds",
-            "Allow hold ('freeze') arrows in songs.",
+  "holds": (True, _("Holds"),
+            _("Allow hold ('freeze') arrows in songs."),
             ON_OFF),
-  "scoring": (False, "Scoring",
-              "The scoring algorithm.",
+  "scoring": (False, _("Scoring"),
+              _("The scoring algorithm."),
               scores.score_opt),
-  "grade": (False, "Grades",
-            "The grading algorithm.",
+  "grade": (False, _("Grades"),
+            _("The grading algorithm."),
             grades.grade_opt),
-  "combo": (False, "Combos",
-             "How your combo increases.",
+  "combo": (False, _("Combos"),
+             _("How your combo increases."),
              combos.combo_opt),
-  "judge": (False, "Judging Method",
-            "How your steps are judged.",
+  "judge": (False, _("Judging Method"),
+            _("How your steps are judged."),
             judge.judge_opt),
-  "judgescale": (False, "Judging Windows",
-                 "The margin of error for your steps.",
+  "judgescale": (False, _("Judging Windows"),
+                 _("The margin of error for your steps."),
                  zip([2.0 - 0.2 * i for i in range(10)],
                      [str(i) for i in range(10)],
-                     ["Window is twice normal size.",
-                      "Window is 9/5 normal size.",
-                      "Window is 8/5 normal size.",
-                      "Window is 7/5 normal size.",
-                      "Window is 6/5 normal size.", "",
-                      "Window is 4/5 normal size.",
-                      "Window is 3/5 normal size.",
-                      "Window is 2/5 normal size.",
-                      "Window is 1/5 normal size."])
+                     [_("Window is twice normal size."),
+                      _("Window is 9/5 normal size."),
+                      _("Window is 8/5 normal size."),
+                      _("Window is 7/5 normal size."),
+                      _("Window is 6/5 normal size."), "",
+                      _("Window is 4/5 normal size."),
+                      _("Window is 3/5 normal size."),
+                      _("Window is 2/5 normal size."),
+                      _("Window is 1/5 normal size.")])
                  ),
 
-  "life": (False, "Life",
-                 "Increase or decrease your amount of (non-battery) life.",
-                 [(0.25, "Undead", "Life is 1/4 the usual amount."),
-                  (0.50, "Very Low", "Life is 1/2 the usual amount."),
-                  (0.75, "Low", "Life is 3/4 the usual amount."),
-                  (1, "Normal", ""),
-                  (1.25, "High", "Life is 5/4 the usual amount."),
-                  (1.50, "Very High", "Life is 3/2 the usual amount."),
-                  (1.75, "Lazarus", "Life is 7/4 the usual amount.")]
+  "life": (False, _("Life"),
+                 _("Increase or decrease your amount of (non-battery) life."),
+                 [(0.25, _("Undead"), _("Life is 1/4 the usual amount.")),
+                  (0.50, _("Very Low"), _("Life is 1/2 the usual amount.")),
+                  (0.75, _("Low"), _("Life is 3/4 the usual amount.")),
+                  (1, _("Normal"), ""),
+                  (1.25, _("High"), _("Life is 5/4 the usual amount.")),
+                  (1.50, _("Very High"), _("Life is 3/2 the usual amount.")),
+                  (1.75, _("Lazarus"), _("Life is 7/4 the usual amount."))]
                  ),
-  "lifebar": (False, "Lifebar",
-              "The kind of lifebar used.",
+  "lifebar": (False, _("Lifebar"),
+              _("The kind of lifebar used."),
               lifebars.lifebar_opt),
-  "onilives": (False, "Oni Lives",
-               "The initial / maximum life in Battery mode.",
+  "onilives": (False, _("Oni Lives"),
+               _("The initial / maximum life in Battery mode."),
                [(i, str(i), "") for i in range(1, 9)]),
-  "secret": (False, "Secret Arrows",
-             "Secret arrow display",
-             [(0, "Off", "Disable secret arrows."),
-              (1, "Invisible", "Enable but don't display them."),
-              (2, "Faint", "Show secret arrows faintly.")]
+  "secret": (False, _("Secret Arrows"),
+             _("Secret arrow display"),
+             [(0, _("Off"), _("Disable secret arrows.")),
+              (1, _("Invisible"), _("Enable but don't display them.")),
+              (2, _("Faint"), _("Show secret arrows faintly."))]
              ),
-  "battle": (False, "Battle Mode",
-             "Arrows start in the center and float outwards.",
+  "battle": (False, _("Battle Mode"),
+             _("Arrows start in the center and float outwards."),
              ON_OFF),
   }
             
@@ -171,10 +173,10 @@
          ]
 
 O_HELP = [
-  "Up / Down: Select option",
-  "Left / Right: Change value",
-  "Start: Return to song selector",
-  "F11: Toggle fullscreen"
+  _("Up / Down: Select option"),
+  _("Left / Right: Change value"),
+  _("Start: Return to song selector"),
+  _("F11: Toggle fullscreen")
   ]
 
 def index_of(value, name):
Index: player.py
===================================================================
--- player.py	(revision 1038)
+++ player.py	(working copy)
@@ -93,8 +93,8 @@
     self.image.fill([0, 0, 0])
     self.image.set_colorkey([0, 0, 0], RLEACCEL)
 
-    self.okimg = fontfx.shadefade("OK", 28, 3, [48, 24], [112, 224, 112])
-    self.ngimg = fontfx.shadefade("NG", 28, 3, [48, 24], [224, 112, 112])
+    self.okimg = fontfx.shadefade(_("OK"), 28, 3, [48, 24], [112, 224, 112])
+    self.ngimg = fontfx.shadefade(_("NG"), 28, 3, [48, 24], [224, 112, 112])
 
     self.rect = self.image.get_rect()
     if player.scrollstyle == 2: self.rect.top = 228
@@ -139,23 +139,23 @@
     self._bottom = 320
     self._centerx = game.sprite_center + (playernum * game.player_offset)
         
-    tx = FONTS[48].size("MARVELOUS")[0] + 4
-    marvelous = fontfx.shadefade("MARVELOUS", 48, 4, [tx, 40], [224, 224, 224])
+    tx = FONTS[48].size(_("MARVELOUS"))[0] + 4
+    marvelous = fontfx.shadefade(_("MARVELOUS"), 48, 4, [tx, 40], [224, 224, 224])
 
-    tx = FONTS[48].size("PERFECT")[0] + 4
-    perfect = fontfx.shadefade("PERFECT", 48, 4, [tx, 40], [224, 224, 32])
+    tx = FONTS[48].size(_("PERFECT"))[0] + 4
+    perfect = fontfx.shadefade(_("PERFECT"), 48, 4, [tx, 40], [224, 224, 32])
 
-    tx = FONTS[48].size("GREAT")[0] + 4
-    great = fontfx.shadefade("GREAT", 48, 4, [tx, 40], [32, 224, 32])
+    tx = FONTS[48].size(_("GREAT"))[0] + 4
+    great = fontfx.shadefade(_("GREAT"), 48, 4, [tx, 40], [32, 224, 32])
 
-    tx = FONTS[48].size("OKAY")[0] + 4
-    okay = fontfx.shadefade("OKAY", 48, 4, [tx, 40], [32, 32, 224])
+    tx = FONTS[48].size(_("OKAY"))[0] + 4
+    okay = fontfx.shadefade(_("OKAY"), 48, 4, [tx, 40], [32, 32, 224])
 
-    tx = FONTS[48].size("BOO")[0] + 4
-    boo = fontfx.shadefade("BOO", 48, 4, [tx, 40], [96, 64, 32])
+    tx = FONTS[48].size(_("BOO"))[0] + 4
+    boo = fontfx.shadefade(_("BOO"), 48, 4, [tx, 40], [96, 64, 32])
 
-    tx = FONTS[48].size("MISS")[0]+4
-    miss = fontfx.shadefade("MISS", 48, 4, [tx, 40], [224, 32, 32])
+    tx = FONTS[48].size(_("MISS"))[0]+4
+    miss = fontfx.shadefade(_("MISS"), 48, 4, [tx, 40], [224, 32, 32])
 
     self._space = FONTS[48].render(" ", True, [0, 0, 0])
 
Index: Makefile.general
===================================================================
--- Makefile.general	(revision 1038)
+++ Makefile.general	(working copy)
@@ -1,6 +1,6 @@
 MANPAGES += docs/man
 UTILS += utils/findbpm.py
-ZIPMODS += config.py announcer.py fontfx.py menus.py menudriver.py gfxtheme.py songselect.py fileparsers.py colors.py player.py endless.py gradescreen.py lyrics.py steps.py util.py error.py options.py games.py judge.py dance.py stepfilters.py gameselect.py lifebars.py scores.py combos.py listener.py grades.py stats.py arrows.py pad.py ui.py courses.py records.py interface.py courseselect.py
+ZIPMODS += config.py announcer.py fontfx.py menus.py menudriver.py gfxtheme.py songselect.py fileparsers.py colors.py player.py endless.py gradescreen.py lyrics.py steps.py util.py error.py options.py games.py judge.py dance.py stepfilters.py gameselect.py lifebars.py scores.py combos.py listener.py grades.py stats.py arrows.py pad.py ui.py courses.py records.py interface.py courseselect.py fonttheme.py i18n.py
 ALLMODS += $(ZIPMODS) constants.py
 
 DATA += themes images sound CREDITS
@@ -9,7 +9,11 @@
 	rm -f *.pyc pydance.zip
 
 distclean: clean
-	rm -f pydance.cfg Makefile
+	rm -f pydance.cfg Makefile po/pydance.pot
 
 pydance.zip:
 	zip pydance.zip $(ZIPMODS)
+
+uptrans:
+	xgettext *.py -o po/pydance.pot
+	#xgettext pydance.py menudriver.py gameselect.py courseselect.py songselect.py scores.py player.py gradescreen.py courseselect.py combos.py constants.py fileparsers.py util.py -o po/pydance.pot
Index: pad.py
===================================================================
--- pad.py	(revision 1038)
+++ pad.py	(working copy)
@@ -9,8 +9,9 @@
 (PASS, QUIT, UP, UPLEFT, LEFT, DOWNLEFT, DOWN, DOWNRIGHT,
  RIGHT, UPRIGHT, CENTER, START, SELECT, SCREENSHOT) = range(14)
 
-NAMES = ["", "quit", "up", "up-left", "left", "down-left", "down",
-         "down-right", "right", "up-right", "center", "start", "select"]
+NAMES = ["", _("quit"), _("up"), _("up-left"), _("left"), _("down-left"),
+        _("down"), _("down-right"), _("right"), _("up-right"), _("center"),
+        _("start"), _("select")]
 
 KEYS = {
   K_ESCAPE: QUIT,
@@ -126,7 +127,7 @@
     try: totaljoy = pygame.joystick.get_count()
     except: totaljoy = 0
 
-    print totaljoy, "joystick(s) found."
+    print totaljoy, _("joystick(s) found.")
 
     # Initialize all the joysticks, print diagnostics.
     for i in range(totaljoy):
@@ -135,7 +136,7 @@
       args = (i, m.get_numaxes(), m.get_numbuttons())
       # One hat is two axes.
       args = (i, m.get_numaxes() + 2 * m.get_numhats(), m.get_numbuttons())
-      print "Joystick %d initialized: %d axes, %d buttons." % args
+      print _("Joystick %d initialized: %d axes, %d buttons.") % args
 
       if args[2] == 32: emsusb2 = i
       elif mat == None and (args[1], args[2]) in MATS: mat = i
@@ -152,29 +153,29 @@
         for ev in self.events.values(): self.states[ev] = False
         loaded_input = True
       except:
-        print "W: Unable to load input configuration file."
+        print _("W: Unable to load input configuration file.")
         loaded_input = False
 
     if loaded_input:
-      print "Loaded input configuration."
+      print _("Loaded input configuration.")
     elif emsusb2 != None:
       self.merge_events(0, emsusb2, A4B16) 
       self.merge_events(1, emsusb2, dict([(k + 16, v) for (k, v) in A4B16.items()]))
-      print "EMSUSB2 found. Using preset EMSUSB2 config."
+      print _("EMSUSB2 found. Using preset EMSUSB2 config.")
     elif mat != None:
       joy = pygame.joystick.Joystick(mat)
       axes, but = joy.get_numaxes() + 2 * joy.get_numhats(), joy.get_numbuttons()
-      print "Initializing player 1 using js%d." % mat
+      print _("Initializing player 1 using js%d.") % mat
       self.merge_events(0, mat, MATS[(axes, but)])
 
       if mat2:
         joy = pygame.joystick.Joystick(mat2)
         axes, but = joy.get_numaxes() + 2 * joy.get_numhats(), joy.get_numbuttons()
-        print "Initializing player 2 using js%d." % mat2
+        print _("Initializing player 2 using js%d.") % mat2
         self.merge_events(1, mat2, MATS[(axes, but)])
     elif totaljoy > 0:
-      print "No known joysticks found! If you want to use yours,"
-      print "you'll have to map its button manually once to use it."
+      print _("No known joysticks found! If you want to use yours,")
+      print _("you'll have to map its button manually once to use it.")
 
     self.merge_events(-1, -1, KEYS)
 
@@ -182,7 +183,7 @@
     pygame.joystick.init()
     try: totaljoy = pygame.joystick.get_count()
     except: totaljoy = 0
-    print totaljoy, "joystick(s) found."
+    print totaljoy, _("joystick(s) found.")
     for i in range(totaljoy): pygame.joystick.Joystick(i).init()
 
   def add_event(self, device, key, pid, event):
@@ -305,10 +306,10 @@
 
     if keyb:
       wanted_type = KEYDOWN
-      text = "Press a key for %s (escape to cancel)" % NAMES[dir]
+      text = _("Press a key for %s (escape to cancel)") % NAMES[dir]
     else:
       wanted_type = JOYBUTTONDOWN
-      text = "Press a button for %s (escape to cancel)" % NAMES[dir]
+      text = _("Press a button for %s (escape to cancel)") % NAMES[dir]
 
     img = FONTS[32].render(text, True, colors.BLACK)
     r = img.get_rect()
@@ -332,8 +333,8 @@
 
     self.screen.blit(PadConfig.bg, [0, 0])
 
-    text = ["Player 1", "Player 2"]
-    text2 = ["Keyboard", "Joystick"]
+    text = [_("Player 1"), _("Player 2")]
+    text2 = [_("Keyboard"), _("Joystick")]
 
     for t in text:
       img = FONTS[32].render(t, True, colors.BLACK)
Index: songselect.py
===================================================================
--- songselect.py	(revision 1038)
+++ songselect.py	(working copy)
@@ -17,6 +17,8 @@
 from pygame.mixer import music
 from fonttheme import FontTheme
 
+from i18n import *
+
 SORTS = {
   "subtitle": lambda x: x.info["subtitle"].lower(),
   "title": lambda x: (x.info["title"].lower(), SORTS["subtitle"](x)),
@@ -44,13 +46,13 @@
 NUM_SORTS = len(SORT_NAMES)
 
 SS_HELP = [
-  "Up / Down: Change song selection",
-  "Left / Right: Change difficulty setting",
-  "Enter / Up Right: Open a folder or start a song",
-  "Escape / Up Left: Closes  folder or exit",
-  "Tab / Select: Go to a random song",
-  "Start: Go to the options screen",
-  "F11: Toggle fullscreen - S: Change the sort mode",
+  _("Up / Down: Change song selection"),
+  _("Left / Right: Change difficulty setting"),
+  _("Enter / Up Right: Open a folder or start a song"),
+  _("Escape / Up Left: Closes  folder or exit"),
+  _("Tab / Select: Go to a random song"),
+  _("Start: Go to the options screen"),
+  _("F11: Toggle fullscreen - S: Change the sort mode"),
   ]
 
 class FolderDisplay(object):
@@ -144,8 +146,8 @@
     songs = [s for s in songs if s.difficulty.has_key(game)]
     
     if len(songs) == 0:
-      error.ErrorMessage(screen, "You don't have any songs for the game mode ("
-                         + game + ") that you selected.")
+      error.ErrorMessage(screen, _("You don't have any songs for the game mode (")
+                         + game + _(") that you selected.")) #TODO: format using % for better i18n
       return
 
 
@@ -214,7 +216,7 @@
               self._song.difficulty[diff_name], grade)
       else:
         self._diff_names.append(" ")        
-        d.set("None", [127, 127, 127], 0, "?")
+        d.set(_("None"), [127, 127, 127], 0, "?")
       self._diff_widgets.append(d)
     
     ActiveIndicator([405, 259], width = 230).add(self._sprites)
@@ -283,16 +285,16 @@
             self._index = self._songitems.index(self._song)      
           else:
             error.ErrorMessage(screen,
-                               "You don't have any songs that are marked " +
-                               "\"valid\" for random selection.")
+                               _("You don't have any songs that are marked ") +
+                               _("\"valid\" for random selection."))
         else:
           valid_songs = [s for s in self._songitems if s.info["valid"]]
           if len(valid_songs) > 0:
             self._song = random.choice(valid_songs)
             self._index = self._songitems.index(self._song)
           else:
-            error.ErrorMessage(screen, "You don't have any songs here that " +
-                               "are marked \"valid\" for random selection.")
+            error.ErrorMessage(screen, _("You don't have any songs here that ") +
+                               _("are marked \"valid\" for random selection."))
       elif ev == ui.START:
         options.OptionScreen(self._configs, self._config, self._screen)
         self._screen.blit(self._bg, [0, 0])
@@ -495,7 +497,7 @@
                  folder in lst]
     self._songitems = new_songs
     self._list.set_items([s.info["title"] for s in self._songitems])
-    self._base_text = "Sort by %s" % sort_name.capitalize()
+    self._base_text = _("Sort by %s") % sort_name.capitalize()
     
   def _create_song_list(self, folder):
     # folder contains a sorting criterion value in string format
Index: images/ready_ca_ES.png
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: images/ready_ca_ES.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Index: images/go_ca_ES.png
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: images/go_ca_ES.png
___________________________________________________________________
Name: svn:mime-type
   + application/octet-stream

Index: menudriver.py
===================================================================
--- menudriver.py	(revision 1038)
+++ menudriver.py	(working copy)
@@ -13,6 +13,8 @@
 from fonttheme import FontTheme
 from gameselect import MainWindow as GameSelect
 
+from i18n import *
+
 class Credits(pygame.sprite.Sprite):
   def __init__(self, lines):
     pygame.sprite.Sprite.__init__(self)
@@ -181,87 +183,87 @@
   try:
     lines = file(os.path.join(pydance_path, "CREDITS")).read().split("\n")
     lines = [l.decode("utf-8") for l in lines]
-    Credits(["pydance %s" % VERSION] + lines).add(sprites)
+    Credits([_("pydance %s") % VERSION] + lines).add(sprites)
   except:
-    Credits(["pydance %s" % VERSION,
+    Credits([_("pydance %s") % VERSION,
              "http://icculus.org/pyddr",
-             "By Joe Wreschnig & Brendan Becker",
-             "(Your CREDITS file is missing.)",
+             _("By Joe Wreschnig & Brendan Becker"),
+             _("(Your CREDITS file is missing.)"),
              ]).add(sprites)
 
-  m = (["Play Game", {ui.START: wrap_ctr, ui.CONFIRM: wrap_ctr},
+  m = ([_("Play Game"), {ui.START: wrap_ctr, ui.CONFIRM: wrap_ctr},
 	(GameSelect, songdata)],
-       ["Map Keys", {ui.START: wrap_ctr, ui.CONFIRM: wrap_ctr},
+       [_("Map Keys"), {ui.START: wrap_ctr, ui.CONFIRM: wrap_ctr},
         (pad.PadConfig, (screen,))],
-       ("Game Options",
-        ["Autofail", onoff_opt, ("autofail",)],
-        ["Assist Mode", tuple_opt, ("assist",
+       (_("Game Options"),
+        [_("Autofail"), onoff_opt, ("autofail",)],
+        [_("Assist Mode"), tuple_opt, ("assist",
                                     [(0, "Off"),
                                      (1, "Click"),
                                      (2, "Full")])],
-        ["Announcer", rotate_opt, ('djtheme', Announcer.themes())],
-        ("Themes ...",
-         ["4 Panel", rotate_opt,
+        [_("Announcer"), rotate_opt, ('djtheme', Announcer.themes())],
+        (_("Themes ..."),
+         [_("4 Panel"), rotate_opt,
           ("4p-theme", ThemeFile.list_themes("SINGLE"))],
-         ["3 Panel", rotate_opt,
+         [_("3 Panel"), rotate_opt,
           ("3p-theme", ThemeFile.list_themes("3PANEL"))],
-         ["5 Panel", rotate_opt,
+         [_("5 Panel"), rotate_opt,
           ("5p-theme", ThemeFile.list_themes("5PANEL"))],
-         ["Large 6 Panel", rotate_opt,
+         [_("Large 6 Panel"), rotate_opt,
           ("6pl-theme", ThemeFile.list_themes("6PANEL"))],
-         ["Small 6 Panel", rotate_opt,
+         [_("Small 6 Panel"), rotate_opt,
           ("6ps-theme", ThemeFile.list_themes("6VERSUS"))],
-         ["Large 8 Panel", rotate_opt,
+         [_("Large 8 Panel"), rotate_opt,
           ("8pl-theme", ThemeFile.list_themes("8PANEL"))],
-         ["Small 8 Panel", rotate_opt,
+         [_("Small 8 Panel"), rotate_opt,
           ("8ps-theme", ThemeFile.list_themes("8VERSUS"))],
-         ["Large 9 Panel", rotate_opt,
+         [_("Large 9 Panel"), rotate_opt,
           ("9pl-theme", ThemeFile.list_themes("9PANEL"))],
-         ["Small 9 Panel", rotate_opt,
+         [_("Small 9 Panel"), rotate_opt,
           ("9ps-theme", ThemeFile.list_themes("9VERSUS"))],
-         ["Parapara", rotate_opt,
+         [_("Parapara"), rotate_opt,
           ("para-theme", ThemeFile.list_themes("PARAPARA"))],
-         ["DMX", rotate_opt,
+         [_("DMX"), rotate_opt,
           ("dmx-theme", ThemeFile.list_themes("DMX"))],
-         ["EZ2", rotate_opt,
+         [_("EZ2"), rotate_opt,
           ("ez2-theme", ThemeFile.list_themes("EZ2SINGLE"))],
-         ["EZ2 Real", rotate_opt,
+         [_("EZ2 Real"), rotate_opt,
           ("ez2real-theme", ThemeFile.list_themes("EZ2REAL"))],
-         ["Back", None, None]
+         [_("Back"), None, None]
          ),
-        ["Back", None, None]
+        [_("Back"), None, None]
         ),
-       ("Graphic Options",
-        ["Animation", onoff_opt, ('animation',)],
-        ["Arrow Effects", rotate_index_opt,
+       (_("Graphic Options"),
+        [_("Animation"), onoff_opt, ('animation',)],
+        [_("Arrow Effects"), rotate_index_opt,
          ('explodestyle', ('none', 'rotate', 'scale', 'rotate & scale'))],
-        ["Backgrounds", onoff_opt, ('showbackground',)],
-        ["Brightness", tuple_opt, ('bgbrightness',
+        [_("Backgrounds"), onoff_opt, ('showbackground',)],
+        [_("Brightness"), tuple_opt, ('bgbrightness',
                                    [(32, 'very dark'),
                                     (64, 'dark'),
                                     (127, 'normal'),
                                     (192, 'bright'),
                                     (255, 'very bright')])],
-        ["Lyrics", onoff_opt, ("showlyrics",)],
-        ["Lyrics Color", rotate_opt, ("lyriccolor",
+        [_("Lyrics"), onoff_opt, ("showlyrics",)],
+        [_("Lyrics Color"), rotate_opt, ("lyriccolor",
                                      ["pink/purple", "purple/cyan",
                                       "cyan/aqua", "aqua/yellow",
                                       "yellow/pink"])],
-        ["Back", None, None]
+        [_("Back"), None, None]
         ),
-       ("Interface Options",
-        ["Save Input", onoff_opt, ('saveinput',)],
-        ["Song Previews", tuple_opt, ('previewmusic',
+       (_("Interface Options"),
+        [_("Save Input"), onoff_opt, ('saveinput',)],
+        [_("Song Previews"), tuple_opt, ('previewmusic',
                                       [(0, "Off"), (1, "On"), (2, "Safe")])],
-        ["Folders", onoff_opt, ("folders",)],
-        ["Timer Display", onoff_opt, ('fpsdisplay',)],
-        ["Song Info Screen", tuple_opt, ('songinfoscreen',
+        [_("Folders"), onoff_opt, ("folders",)],
+        [_("Timer Display"), onoff_opt, ('fpsdisplay',)],
+        [_("Song Info Screen"), tuple_opt, ('songinfoscreen',
                                          zip([0, 1, 2],
                                              ["Never", "Multi-song Only", "Always"]))],
-        ["Font (after restart)", rotate_opt, ('fonttheme', FontTheme.themes())],
-        ["Back", None, None]
+        [_("Font (after restart)"), rotate_opt, ('fonttheme', FontTheme.themes())],
+        [_("Back"), None, None]
         )
        )
 
-  me = menus.Menu("Main Menu", m, screen, sprites)
+  me = menus.Menu(_("Main Menu"), m, screen, sprites)
   me.display()
Index: combos.py
===================================================================
--- combos.py	(revision 1038)
+++ combos.py	(working copy)
@@ -116,6 +116,6 @@
 
 combos = [NormalCombo, OniCombo, PumpCombo]
 combo_opt = [
-  (0, "Normal", "Greats or better increase a combo"),
-  (1, "Oni-style", "Greats don't increase a combo, but also don't break it"),
-  (2, "Pump It Up", "Okays or better increase a combo")]
+  (0, _("Normal"), _("Greats or better increase a combo")),
+  (1, _("Oni-style"), _("Greats don't increase a combo, but also don't break it")),
+  (2, _("Pump It Up"), _("Okays or better increase a combo"))]
Index: courses.py
===================================================================
--- courses.py	(revision 1038)
+++ courses.py	(working copy)
@@ -14,11 +14,13 @@
 import records
 import os
 
+from i18n import *
+
 # The core course class.
 class AbstractCourse(object):
   def __init__(self, all_songs, recordkeys):
     self.songs = []
-    self.name = "A Course"
+    self.name = _("A Course")
     self.mixname = " "
     self.banner = None
     self.all_songs = all_songs
@@ -80,25 +82,25 @@
 
     # Check for player's best/worst/likes/dislikes. There are stored
     # as a tuple of (type, number).
-    if name[0] == "BEST":
+    if name[0] == _("BEST"):
       s = self.recordkeys.get(records.best(name[1], diff, self.gametype), None)
       if s:
         fullname = s.filename
         if isinstance(diff, list):
           diff = [d for d in diff if d in s.difficulty[self.gametype]][0]
-    elif name[0] == "WORST":
+    elif name[0] == _("WORST"):
       s = self.recordkeys.get(records.worst(name[1], diff, self.gametype),None)
       if s:
         fullname = s.filename
         if isinstance(diff, list):
           diff = [d for d in diff if d in s.difficulty[self.gametype]][0]
-    elif name[0] == "LIKES":
+    elif name[0] == _("LIKES"):
       s = self.recordkeys.get(records.like(name[1], diff, self.gametype),None)
       if s:
         fullname = s.filename
         if isinstance(diff, list):
           diff = [d for d in diff if d in s.difficulty[self.gametype]][0]
-    elif name[0] == "DISLIKES":
+    elif name[0] == _("DISLIKES"):
       s = self.recordkeys.get(records.dislike(name[1], diff, self.gametype),None)
       if s:
         fullname = s.filename
@@ -114,7 +116,7 @@
         if folder in self.all_songs:
           songs = [s for s in self.all_songs[folder].values() if (s,diff) not in self.past_songs]
         else:
-          error.ErrorMessage(self.screen, folder + " was not found.")
+          error.ErrorMessage(self.screen, folder + _(" was not found."))
           raise StopIteration
 
       else:
@@ -125,7 +127,7 @@
       songs = [s for s in songs if (s,diff) not in self.past_songs and self._find_difficulty(s, diff)]
 
       if len(songs) == 0:
-        error.ErrorMessage(self.screen, "No valid songs were found.")
+        error.ErrorMessage(self.screen, _("No valid songs were found."))
         raise StopIteration
       else:
         song = random.choice(songs)
@@ -153,8 +155,8 @@
 
     if not fullname:
       if len(name[0]) > 1:
-        name = "Player's %s #%d" % (name[0].capitalize(), name[1])
-      error.ErrorMessage(self.screen, name + "was not found.")
+        name = _("Player's %s #%d") % (name[0].capitalize(), name[1])
+      error.ErrorMessage(self.screen, name + _("was not found."))
       raise StopIteration
 
     self.index += 1
@@ -163,7 +165,7 @@
 
 def CourseFile(*args):
   if args[0].lower().endswith(".crs"): return CRSFile(*args)
-  else: raise RuntimeError(filename + " is an unsupported format.")
+  else: raise RuntimeError(filename + _(" is an unsupported format."))
 
 # Like DWI and SM files, CRS files are a variant of the MSD format.
 # This is the DWI variant of .crs. Stepmania's (incompatible) course
@@ -229,8 +231,8 @@
           modifiers = modifiers.split(",")
         else: continue
 
-        if name[0:4] == "BEST": name = ("BEST", int(name[4:]))
-        elif name[0:5] == "WORST": name = ("WORST", int(name[5:]))
+        if name[0:4] == _("BEST"): name = (_("BEST"), int(name[4:]))
+        elif name[0:5] == _("WORST"): name = (_("WORST"), int(name[5:]))
         else: name = name.replace("\\", "/") # DWI uses Windows-style
 
         # FIXME: This doesn't actually work yet. Modifier application
@@ -256,40 +258,40 @@
 def make_players(all_songs, recordkeys):
   courses = []
   for start, end in [(1, 5), (5, 9), (1, 9)]:
-    for diff_name, diffs in [("(Easy)", ["BASIC", "LIGHT", "EASY"]),
-                             ("(Normal)", ["ANOTHER", "STANDARD", "NORMAL",
+    for diff_name, diffs in [(_("(Easy)"), ["BASIC", "LIGHT", "EASY"]),
+                             (_("(Normal)"), ["ANOTHER", "STANDARD", "NORMAL",
                                            "TRICK", "MEDIUM"]),
-                             ("(Hard)", ["MANIAC", "HEAVY", "HARD"]),
-                             ("(Expert)", ["HARDCORE", "CRAZY", "SMANIAC",
+                             (_("(Hard)"), ["MANIAC", "HEAVY", "HARD"]),
+                             (_("(Expert)"), ["HARDCORE", "CRAZY", "SMANIAC",
                                            "EXPERT"])]:
       # Player's best, worst, likes, and dislikes
-      for name, type in (["Best", "BEST"],
-                         ["Worst", "WORST"],
-                         ["Likes", "LIKES"],
-                         ["Dislikes", "DISLIKES"]):
+      for name, type in ([_("Best"), _("BEST")],
+                         [_("Worst"), _("WORST")],
+                         [_("Likes"), _("LIKES")],
+                         [_("Dislikes"), _("DISLIKES")]):
         realname = "%s %d-%d %s" % (name, start, end - 1, diff_name)
         songs = [((type, i), diffs, {}) for i in range(start, end)]
         courses.append(CodedCourse(all_songs, recordkeys, realname,
-                                   "Player's Picks", songs))
+                                   _("Player's Picks"), songs))
 
   # Random courses.
   for i in [4, 8, 12]:
-    for diff_name, diffs in [("(Easy)", ["BASIC", "LIGHT", "EASY"]),
-                             ("(Normal)", ["ANOTHER", "STANDARD", "NORMAL",
+    for diff_name, diffs in [(_("(Easy)"), ["BASIC", "LIGHT", "EASY"]),
+                             (_("(Normal)"), ["ANOTHER", "STANDARD", "NORMAL",
                                            "TRICK", "MEDIUM"]),
-                             ("(Hard)", ["MANIAC", "HEAVY", "HARD"]),
-                             ("(Expert)", ["HARDCORE", "CRAZY", "SMANIAC",
+                             (_("(Hard)"), ["MANIAC", "HEAVY", "HARD"]),
+                             (_("(Expert)"), ["HARDCORE", "CRAZY", "SMANIAC",
                                            "EXPERT"])]:
-      randname = "Random %d %s" % (i, diff_name)
+      randname = _("Random %d %s") % (i, diff_name)
       randsongs = [("*", diffs, {})] * i
       courses.append(CodedCourse(all_songs, recordkeys, randname,
-                                 "random.choose(songs)", randsongs))
+                                 _("random.choose(songs)"), randsongs))
 
     # ... with random difficulties.
-    randname = "All Random %d" % i
+    randname = _("All Random %d") % i
     randsongs = [("*", "0..10", {})] * i
     courses.append(CodedCourse(all_songs, recordkeys, randname,
-                               "random.choose(songs)", randsongs))
+                               _("random.choose(songs)"), randsongs))
 
   # I like this course.
   d1 = ["MANIAC", "HEAVY", "HARD"]
@@ -297,11 +299,11 @@
   songs1 = []
   songs2 = []
   for i in [29, 23, 19, 17, 13, 11, 7, 5, 3, 2]:
-    songs1.append((("WORST", i), d1, {}))
-    songs2.append((("WORST", i), d2, {}))
+    songs1.append(((_("WORST"), i), d1, {}))
+    songs2.append(((_("WORST"), i), d2, {}))
 
-  courses.append(CodedCourse(all_songs, recordkeys, "Primal Fear (Easy)",
-                              "Player's Picks", songs1))
-  courses.append(CodedCourse(all_songs, recordkeys, "Primal Fear (Hard)",
-                              "Player's Picks", songs2))
+  courses.append(CodedCourse(all_songs, recordkeys, _("Primal Fear (Easy)"),
+                              _("Player's Picks"), songs1))
+  courses.append(CodedCourse(all_songs, recordkeys, _("Primal Fear (Hard)"),
+                              _("Player's Picks"), songs2))
   return courses
Index: pydance.py
===================================================================
--- pydance.py	(revision 1038)
+++ pydance.py	(working copy)
@@ -7,19 +7,21 @@
 
 VERSION = "1.0.3"
 
+from i18n import *
+
 # fuck you, Python.
 def print_help():
   print
-  print "Usage: %s [options]" % sys.argv[0]
-  print " -h, --help         display this help text and exit"
-  print " -v, --version      display the version and exit"
-  print " -f, --filename     load and play a step file"
-  print " -m, --mode         the mode to play the file in (default SINGLE)"
-  print " -d, --difficulty   the difficult to play the file (default BASIC)"
+  print _("Usage: %s [options]") % sys.argv[0]
+  print _(" -h, --help         display this help text and exit")
+  print _(" -v, --version      display the version and exit")
+  print _(" -f, --filename     load and play a step file")
+  print _(" -m, --mode         the mode to play the file in (default SINGLE)")
+  print _(" -d, --difficulty   the difficult to play the file (default BASIC)")
   raise SystemExit
 
 def print_version():
-  print "pydance %s by Joe Wreschnig, Brendan Becker, and others" % VERSION
+  print _("pydance %s by Joe Wreschnig, Brendan Becker, and others") % VERSION
   print "pyddr-discuss@icculus.org - http://icculus.org/pyddr"
   raise SystemExit
 
@@ -57,13 +59,13 @@
     if mainconfig["fullscreen"]: flags |= FULLSCREEN
     screen = pygame.display.set_mode([640, 480], flags, 16)
   except:
-    raise SystemExit("E: Can't get a 16 bit display! pydance doesn't work in 8 bit mode.")
+    raise SystemExit(_("E: Can't get a 16 bit display! pydance doesn't work in 8 bit mode."))
   return screen
 
 # Load a single song (given the filename) and then play it on the
 # given difficulty.
 def play_and_quit(fn, mode, difficulty):
-  print "Entering debug (play-and-quit) mode."
+  print _("Entering debug (play-and-quit) mode.")
   screen = set_display_mode()  
   pygame.display.set_caption("pydance " + VERSION)
   pygame.mouse.set_visible(0)
@@ -83,20 +85,20 @@
   # Remove duplicates
   files = list(dict(map(None, files, [])).keys())
   objects = []
-  message = "Found %d %s. Loading..." % (len(files), type)
+  message = _("Found %d %s. Loading...") % (len(files), type)
   pbar = TextProgress(FontTheme.loadingscreen, message, colors.WHITE, colors.BLACK)
   r = pbar.render(0).get_rect()
   r.center = [320, 240]
   for f in files:
     try: objects.append(Ctr(*((f,) + args)))
     except RuntimeError, message:
-      print "E:", f
-      print "E:", message
+      print _("E:"), f
+      print _("E:"), message
       print
     except Exception, message:
-      print "E: Unknown error loading", f
-      print "E:", message
-      print "E: Please contact the developers (pyddr-devel@icculus.org)."
+      print _("E: Unknown error loading"), f
+      print _("E:"), message
+      print _("E: Please contact the developers (pyddr-devel@icculus.org).")
       print
     pct += inc
     img = pbar.render(pct)
@@ -115,9 +117,9 @@
   if mainconfig["usepsyco"]:
     try:
       import psyco
-      print "Psyco optimizing compiler found. Using psyco.full()."
+      print _("Psyco optimizing compiler found. Using psyco.full().")
       psyco.full()
-    except ImportError: print "W: Psyco optimizing compiler not found."
+    except ImportError: print _("W: Psyco optimizing compiler not found.")
 
   # default settings for play_and_quit.
   mode = "SINGLE"
@@ -126,21 +128,21 @@
   for opt, arg in getopt(sys.argv[1:],
                          "hvf:d:m:", ["help", "version", "filename=",
                                       "difficulty=", "mode="])[0]:
-    if opt in ["-h", "--help"]: print_help()
-    elif opt in ["-v", "--version"]: print_version()
-    elif opt in ["-f", "--filename"]: test_file = arg
-    elif opt in ["-m", "--mode"]: mode = arg
-    elif opt in ["-d", "--difficulty"]: difficulty = arg
+    if opt in ["-h", _("--help")]: print_help()
+    elif opt in ["-v", _("--version")]: print_version()
+    elif opt in ["-f", _("--filename")]: test_file = arg
+    elif opt in ["-m", _("--mode")]: mode = arg
+    elif opt in ["-d", _("--difficulty")]: difficulty = arg
 
   if test_file: play_and_quit(test_file, mode, difficulty)
 
   song_list = []
   course_list = []
   for dir in mainconfig["songdir"].split(os.pathsep):
-    print "Searching for songs in", dir
+    print _("Searching for songs in"), dir
     song_list.extend(util.find(dir, ['*.dance', '*.dwi', '*.sm', '*/song.*']))
   for dir in mainconfig["coursedir"].split(os.pathsep):
-    print "Searching for courses in", dir
+    print _("Searching for courses in"), dir
     course_list.extend(util.find(dir, ['*.crs']))
 
   screen = set_display_mode()
@@ -186,12 +188,12 @@
 
   if len(songs) < 1:
     ErrorMessage(screen,
-                 ("You don't have any songs or step files. Check out "
+                 (_("You don't have any songs or step files. Check out "
                   "http://icculus.org/pyddr/get.php#songs "
                   "and download some free ones. "
-                  "If you already have some, make sure they're in ") +
+                  "If you already have some, make sure they're in ")) +
                  mainconfig["songdir"])
-    raise SystemExit("You don't have any songs. Check http://icculus.org/pyddr/get.php#songs .")
+    raise SystemExit(_("You don't have any songs. Check http://icculus.org/pyddr/get.php#songs ."))
 
   menudriver.do(screen, (songs, crs, screen))
 
Index: po/ca.po
===================================================================
--- po/ca.po	(revision 0)
+++ po/ca.po	(revision 0)
@@ -0,0 +1,1741 @@
+# translation of ca.po to catal
+# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
+# This file is distributed under the same license as the PACKAGE package.
+#
+# Carles Pina i Estany <carles@pina.cat>, 2008.
+msgid ""
+msgstr ""
+"Project-Id-Version: ca\n"
+"Report-Msgid-Bugs-To: \n"
+"POT-Creation-Date: 2008-02-10 19:50+0100\n"
+"PO-Revision-Date: 2008-02-10 17:39+0100\n"
+"Last-Translator: Carles Pina i Estany <carles@pina.cat>\n"
+"Language-Team: catal <carles@pina.cat>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=ISO-8859-15\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Generator: KBabel 1.11.4\n"
+
+#: announcer.py:33
+#, python-format
+msgid "E: Cannot load announcer theme '%s'."
+msgstr "E: No s'ha pogut carregar el tema vocal '%s'."
+
+#: combos.py:119 gameselect.py:24 gameselect.py:73 gameselect.py:82
+#: gameselect.py:158 lifebars.py:218 options.py:44 options.py:54 options.py:64
+#: options.py:74 options.py:80 options.py:87 options.py:105 options.py:147
+msgid "Normal"
+msgstr "Normal"
+
+#: combos.py:119
+msgid "Greats or better increase a combo"
+msgstr "Fantstic o millor incrementa el combo"
+
+#: combos.py:120
+msgid "Oni-style"
+msgstr "Estil-Oni"
+
+#: combos.py:120
+msgid "Greats don't increase a combo, but also don't break it"
+msgstr "Fantstics no incrementen el combo, per el posen a zero"
+
+#: combos.py:121
+msgid "Pump It Up"
+msgstr "Pump It Up"
+
+#: combos.py:121
+msgid "Okays or better increase a combo"
+msgstr "Correcte o millor incrementa el combo"
+
+#: courseselect.py:38 songselect.py:49
+msgid "Up / Down: Change song selection"
+msgstr "Amunt / Avall: selecciona la can"
+
+#: courseselect.py:39 songselect.py:50
+msgid "Left / Right: Change difficulty setting"
+msgstr "Esquerra / Dreta: canvia la dificultat"
+
+#: courseselect.py:40
+msgid "Enter / Up Right: Open a folder or start a course"
+msgstr "Retorn / Amunt Dreta: obre carpeta o recopilaci"
+
+#: courseselect.py:41
+msgid "Escape / Up Left: Close a folder or exit"
+msgstr "ESC / Amunt Esquerra: tanca una carpeta o surt"
+
+#: courseselect.py:42
+msgid "Tab / Select: Go to a random course"
+msgstr "Tab / Select: vs a una recopilaci aleatoria"
+
+#: courseselect.py:43
+msgid "Start: Switch to Options screen"
+msgstr "Start: vs a la pantalla d'opcions"
+
+#: courseselect.py:44 songselect.py:55
+msgid "F11: Toggle fullscreen - S: Change the sort mode"
+msgstr "F11: canvia a pantalla completa - S: Canvia l'ordenaci"
+
+#: courseselect.py:70 courses.py:85 courses.py:234 courses.py:268
+msgid "BEST"
+msgstr "EL MILLOR"
+
+#: courseselect.py:73
+#, python-format
+msgid " (Best #%d)"
+msgstr " (La %da millor)"
+
+#: courseselect.py:76
+msgid "Player's Best Unavailable"
+msgstr "No hi ha estadstiques del millor jugador"
+
+#: courseselect.py:77 courseselect.py:86 courseselect.py:95
+#: courseselect.py:105
+msgid "(You need to play more songs!)"
+msgstr "(Has de ballar ms canons!)"
+
+#: courseselect.py:79 courses.py:91 courses.py:235 courses.py:269
+#: courses.py:302 courses.py:303
+msgid "WORST"
+msgstr "EL PITJOR"
+
+#: courseselect.py:85
+msgid "Player's Worst Unavailable"
+msgstr "No hi ha estadstiques del pitjor jugador"
+
+#: courseselect.py:88 courses.py:97 courses.py:270
+msgid "LIKES"
+msgstr "PREFERIDES"
+
+#: courseselect.py:94
+msgid "Player's Likes Unavailable"
+msgstr "Preferides pel jugador no disponibles"
+
+#: courseselect.py:97 courses.py:103 courses.py:271
+msgid "DISLIKES"
+msgstr "ODIADES"
+
+#: courseselect.py:104
+msgid "Player's Dislikes Unavailable"
+msgstr "Odiades pel jugador no disponibles"
+
+#: courseselect.py:214
+msgid "All Courses"
+msgstr "Totes les recopilacions"
+
+#: courseselect.py:369 songselect.py:500
+#, python-format
+msgid "Sort by %s"
+msgstr "Ordena per %s"
+
+#: courses.py:23
+msgid "A Course"
+msgstr "Una recopilaci"
+
+#: courses.py:119
+msgid " was not found."
+msgstr " no s'ha trobat."
+
+#: courses.py:130
+msgid "No valid songs were found."
+msgstr "No hi ha canons vlides."
+
+#: courses.py:158
+#, python-format
+msgid "Player's %s #%d"
+msgstr "%s del jugador #%d"
+
+#: courses.py:159
+msgid "was not found."
+msgstr "no s'ha trobat."
+
+#: courses.py:168 fileparsers.py:806
+msgid " is an unsupported format."
+msgstr " s un format no suportat."
+
+#: courses.py:261 courses.py:279
+msgid "(Easy)"
+msgstr "(Fcil)"
+
+#: courses.py:262 courses.py:280
+msgid "(Normal)"
+msgstr "(Normal)"
+
+#: courses.py:264 courses.py:282
+msgid "(Hard)"
+msgstr "(Difcil)"
+
+#: courses.py:265 courses.py:283
+msgid "(Expert)"
+msgstr "(Expert)"
+
+#: courses.py:268
+msgid "Best"
+msgstr "Millor"
+
+#: courses.py:269
+msgid "Worst"
+msgstr "Pitjor"
+
+#: courses.py:270
+msgid "Likes"
+msgstr "Agrada"
+
+#: courses.py:271
+msgid "Dislikes"
+msgstr "Desagrada"
+
+#: courses.py:275 courses.py:306 courses.py:308
+msgid "Player's Picks"
+msgstr "Escollides pel jugador"
+
+#: courses.py:285
+#, python-format
+msgid "Random %d %s"
+msgstr "Aleatori %d %s"
+
+#: courses.py:288 courses.py:294
+msgid "random.choose(songs)"
+msgstr "seleccio.aleatoria(cano)"
+
+#: courses.py:291
+#, python-format
+msgid "All Random %d"
+msgstr "Tot aleatori %d"
+
+#: courses.py:305
+msgid "Primal Fear (Easy)"
+msgstr "Primera por (Fcil)"
+
+#: courses.py:307
+msgid "Primal Fear (Hard)"
+msgstr "Primera por (Difcil)"
+
+#: dance.py:221
+msgid "Next Song"
+msgstr "Segent Can"
+
+#: dance.py:222
+msgid "Confirm: Begin   Cancel: Stop"
+msgstr "Confirma: Comea Cancella: Stop"
+
+#: dance.py:223
+msgid "Start: Change Options"
+msgstr "Start: Opcions d'interfcie"
+
+#: dance.py:260 endless.py:37
+#, python-format
+msgid "Player %d"
+msgstr "Jugador %d"
+
+#: dance.py:283
+msgid "Default Settings"
+msgstr "Parmetres per defecte"
+
+#: dance.py:314
+msgid "There was an error loading "
+msgstr "E: Error desconegut carregant"
+
+#: dance.py:333
+msgid "Playing"
+msgstr "Reprodunt"
+
+#: dance.py:430
+msgid "The audio file for this song "
+msgstr "El fitxer d'audio per aquesta can"
+
+#: dance.py:431
+msgid " could not be found."
+msgstr " no s'ha pogut trobar."
+
+#: dance.py:517
+msgid "Saving a screenshot to"
+msgstr "Desant captura pantalla a"
+
+#: dance.py:531
+#, python-format
+msgid "Average FPS for this song was %d."
+msgstr "Promig FPS per aquesta can era %d."
+
+#: endless.py:19
+msgid "Left: Make the songs that will be played easier"
+msgstr "Esquerre: Fes les canons a ser jugades ms fcli"
+
+#: endless.py:20
+msgid "Right: Make the songs that will be played harder"
+msgstr "Dreta. Fes les canons a ser jugades ms difcil"
+
+#: endless.py:21
+msgid "Up: Select difficulty by name"
+msgstr "Amunt: Selecciona la dificultat per nom"
+
+#: endless.py:22
+msgid "Down: Select difficulty by rating"
+msgstr "Avall: Selecciona la dificultat per valoraci"
+
+#: endless.py:23
+msgid "Enter / Up Right: Start playing songs until you fail"
+msgstr "Enter/Amunt Dreta: Comena a jugar fins a defallir"
+
+#: endless.py:24
+msgid "Escape / Up Left: Go back to the game selection screen"
+msgstr "ESC / Amunt esquerre: Ves endarrera a la pantalla de selecci de joc"
+
+#: endless.py:25
+msgid "Start: Go to the options screen / F11: Toggle fullscreen"
+msgstr "Start: anar a la pantalla d'opcions"
+
+#: endless.py:46
+msgid "Select by Difficulty"
+msgstr "Selecciona per dificultat"
+
+#: endless.py:50
+msgid "Select by Rating"
+msgstr "Seleccioneu un Joc"
+
+#: endless.py:51
+#, python-format
+msgid "Between %d and %d"
+msgstr "Entre %d i %d"
+
+#: endless.py:113
+msgid "The difficulty settings you chose result "
+msgstr "Els parmetres de dificultat que has escollit resulten"
+
+#: endless.py:114
+msgid "in no songs being available to play."
+msgstr "no hi ha canons disponibles per ser jugades."
+
+#: endless.py:148
+msgid "You need more songs to play Endless Mode. "
+msgstr "Necessites ms canons per jugar amb mode Sense Fi."
+
+#: endless.py:149
+msgid "Otherwise, it's just really boring."
+msgstr "Altrament, seria aborrit."
+
+#: fileparsers.py:788
+msgid "No Mix"
+msgstr "Sense Mix"
+
+#: fileparsers.py:789
+msgid "Untitled"
+msgstr "Sense Ttol"
+
+#: fileparsers.py:791 fileparsers.py:792
+msgid "Unknown"
+msgstr "Desconegut"
+
+#: fileparsers.py:812
+msgid " is missing: "
+msgstr " est ausent: "
+
+#: fileparsers.py:818
+#, python-format
+msgid "W: Non-Unicode key in %s: %s"
+msgstr "W: Clau No-Unicode a %s: %s"
+
+#: gameselect.py:13
+msgid "Up / Down: Change game, mode, or interface"
+msgstr "Amunt/Avall: canviar el tipus de joc, mode o interfcie"
+
+#: gameselect.py:14
+msgid "Enter / Up Right: Advance your choice"
+msgstr "Enter / Amunt dreta: avana la teva selecci"
+
+#: gameselect.py:15
+msgid "Escape / Up Left: Back up or exit"
+msgstr "Escape / Amunt Esquerre: retrocedeix amunt o surt"
+
+#: gameselect.py:16
+msgid "F11: Toggles fullscreen"
+msgstr "F11: Conmuta a pantalla completa"
+
+#: gameselect.py:17
+#, python-format
+msgid "Enjoy pydance %s!"
+msgstr "Disfruta pydance %s!"
+
+#: gameselect.py:21 gameselect.py:60 gameselect.py:87 gameselect.py:88
+#: gameselect.py:89 gameselect.py:90 gameselect.py:139 gameselect.py:190
+#: gameselect.py:191 gameselect.py:199
+msgid "4 panel"
+msgstr "panell 4 "
+
+#: gameselect.py:21 gameselect.py:61 gameselect.py:97 gameselect.py:98
+#: gameselect.py:99 gameselect.py:100 gameselect.py:142
+msgid "5 panel"
+msgstr "panell 5"
+
+#: gameselect.py:21 gameselect.py:62 gameselect.py:102 gameselect.py:103
+#: gameselect.py:104 gameselect.py:105 gameselect.py:143
+msgid "6 panel"
+msgstr "panell 6"
+
+#: gameselect.py:21 gameselect.py:63 gameselect.py:107 gameselect.py:108
+#: gameselect.py:109 gameselect.py:110 gameselect.py:144
+msgid "8 panel"
+msgstr "panell 8"
+
+#: gameselect.py:21 gameselect.py:64 gameselect.py:112 gameselect.py:113
+#: gameselect.py:114 gameselect.py:115 gameselect.py:145
+msgid "9 panel"
+msgstr "panell 9"
+
+#: gameselect.py:22 gameselect.py:65 gameselect.py:117 gameselect.py:118
+#: gameselect.py:119 gameselect.py:120 gameselect.py:146 menudriver.py:224
+msgid "Parapara"
+msgstr "Parapara"
+
+#: gameselect.py:22 gameselect.py:68 gameselect.py:122 gameselect.py:123
+#: gameselect.py:124 gameselect.py:125 gameselect.py:147 menudriver.py:226
+msgid "DMX"
+msgstr "DMX"
+
+#: gameselect.py:22 gameselect.py:67 gameselect.py:127 gameselect.py:128
+#: gameselect.py:129 gameselect.py:130 gameselect.py:150 menudriver.py:228
+msgid "EZ2"
+msgstr "EZ2"
+
+#: gameselect.py:22 gameselect.py:66 gameselect.py:132 gameselect.py:133
+#: gameselect.py:134 gameselect.py:135 gameselect.py:151 menudriver.py:230
+msgid "EZ2 Real"
+msgstr "EZ2 Real"
+
+#: gameselect.py:22 gameselect.py:59 gameselect.py:92 gameselect.py:93
+#: gameselect.py:94 gameselect.py:95 gameselect.py:141
+msgid "3 panel"
+msgstr "panell 3"
+
+#: gameselect.py:23 gameselect.py:69 gameselect.py:87 gameselect.py:92
+#: gameselect.py:97 gameselect.py:102 gameselect.py:107 gameselect.py:112
+#: gameselect.py:117 gameselect.py:122 gameselect.py:127 gameselect.py:132
+#: gameselect.py:153
+msgid "Single"
+msgstr "Sol "
+
+#: gameselect.py:23 gameselect.py:70 gameselect.py:88 gameselect.py:93
+#: gameselect.py:98 gameselect.py:103 gameselect.py:108 gameselect.py:113
+#: gameselect.py:118 gameselect.py:123 gameselect.py:128 gameselect.py:133
+#: gameselect.py:154
+msgid "Versus"
+msgstr "Versus"
+
+#: gameselect.py:23 gameselect.py:71 gameselect.py:90 gameselect.py:95
+#: gameselect.py:100 gameselect.py:105 gameselect.py:110 gameselect.py:115
+#: gameselect.py:120 gameselect.py:125 gameselect.py:130 gameselect.py:135
+#: gameselect.py:156
+msgid "Double"
+msgstr "Doble"
+
+#: gameselect.py:23 gameselect.py:72 gameselect.py:89 gameselect.py:94
+#: gameselect.py:99 gameselect.py:104 gameselect.py:109 gameselect.py:114
+#: gameselect.py:119 gameselect.py:124 gameselect.py:129 gameselect.py:134
+#: gameselect.py:155
+msgid "Couple"
+msgstr "Parella"
+
+#: gameselect.py:24 gameselect.py:74 gameselect.py:81 gameselect.py:160
+msgid "Nonstop"
+msgstr "NoParar"
+
+#: gameselect.py:24 gameselect.py:75 gameselect.py:80 gameselect.py:159
+msgid "Endless"
+msgstr "Sense fi"
+
+#: gameselect.py:139
+msgid "The standard up, down, left and right arrows "
+msgstr "Les fletxes estndard amunt, avall, esquerre i dreta "
+
+#: gameselect.py:140
+msgid "like Dance Dance Revolution)"
+msgstr "com Dance Dance Revolution)"
+
+#: gameselect.py:141
+msgid "Practice using up left and up right with easier steps."
+msgstr "Practiqueu utilitzant amunt esquerre i amunt dreta amb passos fcils."
+
+#: gameselect.py:142
+msgid "Diagonal arrows and the center (like Pump It Up)"
+msgstr "Flectes diagonals i amb centre (com inflant)"
+
+#: gameselect.py:143
+msgid "Four panel plus the upper diagonal arrows (like DDR Solo)"
+msgstr "Panell quatre amb fletxes diagonal cap amunt (com DDR Solo)"
+
+#: gameselect.py:144
+msgid "Everything but the center (like Technomotion)"
+msgstr "Tot per el centre (com Technomotion)"
+
+#: gameselect.py:145
+msgid "Everything! (like Pop'n'Stage)"
+msgstr "Tot! (com Pop'n'Stage)"
+
+#: gameselect.py:146
+msgid "Wave your arms (or feet) around"
+msgstr "Mou els teus braos (o peus) al voltant"
+
+#: gameselect.py:147
+msgid "Crazy kung-fu action (like Dance ManiaX / Freaks). "
+msgstr "Acci kung-fu boja (com ManiaX Dance / Freaks)"
+
+#: gameselect.py:148
+msgid "Use left, up left, up right, and right."
+msgstr "Useu esquerre, amunt esquerre, amunt dreta i dreta."
+
+#: gameselect.py:150
+msgid "Three panels, two sensors, using left and right."
+msgstr "Tres panells, dos sensors, utilitzant esquerre i dreta."
+
+#: gameselect.py:151
+msgid "Three panels and four sensors."
+msgstr "Tres panells i quatre sensors."
+
+#: gameselect.py:153
+msgid "Play by yourself."
+msgstr "Jugueu vosaltres mateix."
+
+#: gameselect.py:154
+msgid "Challenge an opponent to the same steps."
+msgstr "Desafieu a l'oponent amb els mateixos passos."
+
+#: gameselect.py:155
+msgid "Two people dance different steps to the same song."
+msgstr "Dos persones ballen diferents passos amb la mateixa can."
+
+#: gameselect.py:156
+msgid "Try playing on both sides at once."
+msgstr "Trieu joc els dos costats a la vegada."
+
+#: gameselect.py:158
+msgid "Play one song at a time."
+msgstr "Jugueu amb una can cada vegada."
+
+#: gameselect.py:159
+msgid "Keep dancing until you fail."
+msgstr "Segueix ballant fins a desfallir."
+
+#: gameselect.py:160
+msgid "Play several songs in a row."
+msgstr "Jugueu diferents canons en fila."
+
+#: gameselect.py:170
+msgid "Select a Game"
+msgstr "Seleccioneu un Joc"
+
+#: gameselect.py:170
+msgid "Select a Mode"
+msgstr "Seleccioneu un Mode"
+
+#: gameselect.py:170
+msgid "Select Type"
+msgstr "Seleccioneu un Tipus"
+
+#: gradescreen.py:42
+msgid "Press Escape/Confirm/Start"
+msgstr "Presiona Escape/Confirma/Start"
+
+#: gradescreen.py:209
+#, python-format
+msgid "GRADE: %s (%s) - total steps: %d; best combo: %d"
+msgstr "GRAU: %s (%s) - passes totals: %d millor combo: %d"
+
+#: gradescreen.py:210
+#, python-format
+msgid "V: %d P: %d G: %d O: %d B: %d M: %d - %d/%d holds"
+msgstr "V: %d P: %d G: %d O: %d B: %d M: %d - %d/%d agafades"
+
+#: gradescreen.py:212
+#, python-format
+msgid "Average off: %0.3f, standard deviation %0.2f"
+msgstr "Promig de: %03f desviaci estndard %0.2f"
+
+#: gradescreen.py:232 gradescreen.py:254
+msgid "MARVEL.:"
+msgstr "MERA.:"
+
+#: gradescreen.py:233 gradescreen.py:255
+msgid "PERFECT:"
+msgstr "PERFECTE:"
+
+#: gradescreen.py:234 gradescreen.py:256
+msgid "GREAT:"
+msgstr "FANT.:"
+
+#: gradescreen.py:235 gradescreen.py:257
+msgid "OKAY:"
+msgstr "D'ACOR:"
+
+#: gradescreen.py:236 gradescreen.py:258
+msgid "BOO:"
+msgstr "BUU!:"
+
+#: gradescreen.py:237 gradescreen.py:259
+msgid "MISS:"
+msgstr "DESCU:"
+
+#: gradescreen.py:238 gradescreen.py:260
+msgid "Score:"
+msgstr "Puntuaci:"
+
+#: gradescreen.py:239 gradescreen.py:261
+msgid "Holds:"
+msgstr "Aguantat:"
+
+#: gradescreen.py:241 gradescreen.py:263
+msgid "Max Combo:"
+msgstr "Combo mx:"
+
+#: gradescreen.py:242 gradescreen.py:264
+msgid "Early:"
+msgstr "Abans:"
+
+#: gradescreen.py:243 gradescreen.py:265
+msgid "Late:"
+msgstr "Desprs:"
+
+#: gradescreen.py:244 gradescreen.py:266
+msgid "TOTAL:"
+msgstr "TOTAL:"
+
+#: gradescreen.py:246
+msgid "rating-"
+msgstr "classificaci"
+
+#: judge.py:144
+msgid "Judging is based on how many seconds you are from the correct time."
+msgstr "El judici est basat a quants segons estas fora del temps correcte."
+
+#: judge.py:146
+msgid "Judging is based on how many beats you are from the correct time."
+msgstr "El judici est basat a quants impulsos estas lluny del temps correcte."
+
+#: lifebars.py:23
+msgid "FAILED"
+msgstr "FALLAT"
+
+#: lifebars.py:219
+msgid "Battery"
+msgstr "Bateria"
+
+#: lifebars.py:219
+msgid "A few points of life, increasing each song."
+msgstr "Uns quants punts de vida, incrementant per cada can."
+
+#: lifebars.py:220
+msgid "Power Drop"
+msgstr "Poder Caigut"
+
+#: lifebars.py:220
+msgid "Like normal, but never goes back up."
+msgstr "Com normal, per mai va endarrera."
+
+#: lifebars.py:221
+msgid "Mediocre"
+msgstr "Mediocre"
+
+#: lifebars.py:221
+msgid "Fail if you do too poorly or too well."
+msgstr "Falla si ho fassa massa malament o massa b."
+
+#: lifebars.py:222
+msgid "Tug of War"
+msgstr "Remolcador de la Guerra"
+
+#: lifebars.py:222
+msgid "Fight with the other player for life."
+msgstr "Lluita amb un altre jugador per la vida."
+
+#: lifebars.py:223
+msgid "Great Attack"
+msgstr "Bon Atac"
+
+#: lifebars.py:223
+msgid "Only greats make the bar go up."
+msgstr "Noms fantstic fa anar la barra amunt."
+
+#: menudriver.py:186 menudriver.py:188
+#, python-format
+msgid "pydance %s"
+msgstr "pydance %s"
+
+#: menudriver.py:190
+msgid "By Joe Wreschnig & Brendan Becker"
+msgstr "pydance %s per Joe Wreschning, Brendan Becker, i altres"
+
+#: menudriver.py:191
+msgid "(Your CREDITS file is missing.)"
+msgstr "(El fitxer CREDITS no hi s.)"
+
+#: menudriver.py:194
+msgid "Play Game"
+msgstr "Juga joc"
+
+#: menudriver.py:196
+msgid "Map Keys"
+msgstr "Mapejar Tecles"
+
+#: menudriver.py:198
+msgid "Game Options"
+msgstr "Opcions de Joc"
+
+#: menudriver.py:199
+msgid "Autofail"
+msgstr "Autofallada"
+
+#: menudriver.py:200
+msgid "Assist Mode"
+msgstr "Mode assistent"
+
+#: menudriver.py:204
+msgid "Announcer"
+msgstr "Anunciador"
+
+#: menudriver.py:205
+msgid "Themes ..."
+msgstr "Temes..."
+
+#: menudriver.py:206
+msgid "4 Panel"
+msgstr "Panell 4"
+
+#: menudriver.py:208
+msgid "3 Panel"
+msgstr "Panell 3"
+
+#: menudriver.py:210
+msgid "5 Panel"
+msgstr "Panell 5"
+
+#: menudriver.py:212
+msgid "Large 6 Panel"
+msgstr "Panell 6 gran"
+
+#: menudriver.py:214
+msgid "Small 6 Panel"
+msgstr "Panell 6 petit"
+
+#: menudriver.py:216
+msgid "Large 8 Panel"
+msgstr "Panell 8 gran"
+
+#: menudriver.py:218
+msgid "Small 8 Panel"
+msgstr "Panell 8 petit"
+
+#: menudriver.py:220
+msgid "Large 9 Panel"
+msgstr "Panell 9 gran"
+
+#: menudriver.py:222
+msgid "Small 9 Panel"
+msgstr "Panell 9 petit"
+
+#: menudriver.py:232 menudriver.py:234 menudriver.py:252 menudriver.py:264
+msgid "Back"
+msgstr "Endarrera"
+
+#: menudriver.py:236
+msgid "Graphic Options"
+msgstr "Opcions Grfiques"
+
+#: menudriver.py:237
+msgid "Animation"
+msgstr "Animaci"
+
+#: menudriver.py:238
+msgid "Arrow Effects"
+msgstr "Efectes de fletxa"
+
+#: menudriver.py:240
+msgid "Backgrounds"
+msgstr "Fons"
+
+#: menudriver.py:241
+msgid "Brightness"
+msgstr "Brillantor"
+
+#: menudriver.py:247
+msgid "Lyrics"
+msgstr "Lletres"
+
+#: menudriver.py:248
+msgid "Lyrics Color"
+msgstr "Color Lletres"
+
+#: menudriver.py:254
+msgid "Interface Options"
+msgstr "Opcions d'interfcie"
+
+#: menudriver.py:255
+msgid "Save Input"
+msgstr "Desa Entrada"
+
+#: menudriver.py:256
+msgid "Song Previews"
+msgstr "Previsualitzar Canons"
+
+#: menudriver.py:258
+msgid "Folders"
+msgstr "Carpetes"
+
+#: menudriver.py:259
+msgid "Timer Display"
+msgstr "Mostra Comptador"
+
+#: menudriver.py:260
+msgid "Song Info Screen"
+msgstr "Pantalla d'informaci de la can"
+
+#: menudriver.py:263
+msgid "Font (after restart)"
+msgstr "Tipus de lletra (desprs de reiniciar)"
+
+#: menudriver.py:268
+msgid "Main Menu"
+msgstr "Men Principal"
+
+#: options.py:20 options.py:95 options.py:160
+msgid "Off"
+msgstr "Apagat"
+
+#: options.py:20 options.py:95
+msgid "On"
+msgstr "Engegat"
+
+#: options.py:34
+msgid "Speed"
+msgstr "Velocitat"
+
+#: options.py:35
+msgid "Adjust the speed at which the arrows scroll across the screen."
+msgstr "Ajustar la velocitat que les fletxes d'scroll atravessen la pantalla."
+
+#: options.py:39
+msgid "Arrows scroll at 200bpm."
+msgstr "Fletxes d'scroll a 200bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 300bpm."
+msgstr "Fletxes d'scroll a 300bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 400bpm."
+msgstr "Fletxes d'scroll a 400bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 500bpm."
+msgstr "Fletxes d'scroll a 500bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 600bpm."
+msgstr "Fletxes d'scroll a 600bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 700bpm."
+msgstr "Fletxes d'scroll a 700bpm."
+
+#: options.py:39
+msgid "Arrows scroll at 800bpm."
+msgstr "Fletxes d'scroll a 800bpm."
+
+#: options.py:41
+msgid "Transform"
+msgstr "Transforma"
+
+#: options.py:42
+msgid "Change the step patterns for the song."
+msgstr "Canvia els patrons de passos per la can."
+
+#: options.py:44
+msgid "Mirror"
+msgstr "Mirall"
+
+#: options.py:44
+msgid "Left"
+msgstr "Esquerra"
+
+#: options.py:44
+msgid "Right"
+msgstr "Dreta"
+
+#: options.py:44
+msgid "Shuffle"
+msgstr "Aleatori2"
+
+#: options.py:44
+msgid "Random"
+msgstr "Aleatori %d %s"
+
+#: options.py:45
+msgid "Rotate the steps 180 degrees."
+msgstr "Rotar els passos 180 graus."
+
+#: options.py:46
+msgid "Rotate the steps 90 degrees to the left."
+msgstr "Rotar els passos 90 graus a l'esquerre."
+
+#: options.py:47
+msgid "Rotate the steps 90 degrees to the right."
+msgstr "Rotar les passos 90 graus a la dreta."
+
+#: options.py:48
+msgid "Swap all arrows from one direction to another."
+msgstr "Intercanviar totes les fletxes d'una direcci a una altra."
+
+#: options.py:49
+msgid "Use totally random directions."
+msgstr "Utilitzar direccions totalmente aleatories."
+
+#: options.py:51
+msgid "Add/Remove Steps"
+msgstr "Afegir/treure passos"
+
+#: options.py:52
+msgid "Add or remove arrows from step patterns."
+msgstr "Afegir o treure fletxes dels patrons de passos."
+
+#: options.py:54
+msgid "Tiny"
+msgstr "nfim"
+
+#: options.py:54
+msgid "Little"
+msgstr "Petit"
+
+#: options.py:54
+msgid "Big"
+msgstr "Gran"
+
+#: options.py:54
+msgid "Quick"
+msgstr "Rpid"
+
+#: options.py:54
+msgid "Skippy"
+msgstr "MoltRpid"
+
+#: options.py:55
+msgid "Only dance to on-beat notes."
+msgstr "Noms una dana amb notes de pulsos."
+
+#: options.py:56
+msgid "Only dance to on-beat and half-beat notes."
+msgstr "Noms una dana amb notes de pulsos de meitat."
+
+#: options.py:57
+msgid "Add half-beat steps between on-beat ones."
+msgstr "Afegeix la meitat de pulsos entre NOSQU"
+
+#: options.py:58
+msgid "Add steps between half-beat ones."
+msgstr "Afegeix passos entre els pulsos."
+
+#: options.py:59
+msgid "Add gallops between on-beat steps."
+msgstr "Afegir galops entre els passos."
+
+#: options.py:61
+msgid "Fade"
+msgstr "Desaparixer"
+
+#: options.py:62
+msgid "Fade arrows in or out while they scroll."
+msgstr "Descolorir les fletxes adins o fora de l'scroll."
+
+#: options.py:64
+msgid "Sudden"
+msgstr "De cop"
+
+#: options.py:64
+msgid "Hidden"
+msgstr "Amagat"
+
+#: options.py:64
+msgid "Peek"
+msgstr "peekCAT"
+
+#: options.py:64
+msgid "Cycle"
+msgstr "Cicle"
+
+#: options.py:64
+msgid "Stealth"
+msgstr "Amagat"
+
+#: options.py:65
+msgid "Only display arrows near the top."
+msgstr "Noms mostrar fletxes aprop de dalt."
+
+#: options.py:66
+msgid "Only display arrows near the bottom."
+msgstr "Noms mostrar fletxes aprop de sota."
+
+#: options.py:67
+msgid "Only display arrows near the middle."
+msgstr "Noms mostrar fletxes al mig."
+
+#: options.py:68
+msgid "Blink arrows in and out."
+msgstr "Pampalluguejar les fletxes dins i fora."
+
+#: options.py:69
+msgid "No arrows are displayed."
+msgstr "No es mostren fletxes."
+
+#: options.py:71
+msgid "Acceleration"
+msgstr "Acceleraci."
+
+#: options.py:72
+msgid "Accelerate or decelerate arrows."
+msgstr "Accelerar o frenar les fletxes."
+
+#: options.py:74
+msgid "Brake"
+msgstr "Endarrera"
+
+#: options.py:74
+msgid "Boost"
+msgstr "Millor"
+
+#: options.py:75
+msgid "Decelerate near the top"
+msgstr "Desaccelarar aprop de dalt."
+
+#: options.py:75
+msgid "Accelerate near the top."
+msgstr "Accelerar aprop de dalt."
+
+#: options.py:77
+msgid "Size"
+msgstr "Sol "
+
+#: options.py:78
+msgid "Change arrow sizes."
+msgstr "Canviar la mida de les fletxes."
+
+#: options.py:80
+msgid "Shrink"
+msgstr "Empetitir"
+
+#: options.py:80
+msgid "Grow"
+msgstr "Crixer"
+
+#: options.py:81
+msgid "Smaller arrows near the top."
+msgstr "Encongir fletxes aprop de dalt."
+
+#: options.py:82
+msgid "Smaller arrows near the bottom."
+msgstr "Empetitir fletxes aprop de baix."
+
+#: options.py:84
+msgid "Direction"
+msgstr "Direcci"
+
+#: options.py:85
+msgid "Change the direction arrows scroll."
+msgstr "Canviar la direcci de les fletxes d'scroll"
+
+#: options.py:87
+msgid "Reverse"
+msgstr "Capgirar"
+
+#: options.py:87
+msgid "Center"
+msgstr "Centrar"
+
+#: options.py:88
+msgid "Arrows go from bottom to top."
+msgstr "Flectes de baix a dalt."
+
+#: options.py:89
+msgid "Arrows go from top to bottom."
+msgstr "Fletxes de dalt a baix."
+
+#: options.py:90
+msgid "Arrows go from the top and bottom to the center."
+msgstr "Flectes de dalt a baix i cap al centre."
+
+#: options.py:92
+msgid "Jumps"
+msgstr "Salts"
+
+#: options.py:93
+msgid "Turn jumps off, or add more."
+msgstr "Parar salts o afegir-ne."
+
+#: options.py:95
+msgid "Wide"
+msgstr "Ample"
+
+#: options.py:96
+msgid "Remove jumps from the song."
+msgstr "Treure els salts de la can."
+
+#: options.py:97
+msgid "Add jumps on every on-beat step."
+msgstr "Afegir salts a cada puls de pas."
+
+#: options.py:99
+msgid "Spin"
+msgstr "Sol "
+
+#: options.py:100
+msgid "Rotate arrows as they go up the screen."
+msgstr "Start: anar a la pantalla d'opcions"
+
+#: options.py:102
+msgid "Colors"
+msgstr "Carpetes"
+
+#: options.py:103
+msgid "Use colors of arrows to indicate the beat."
+msgstr "Utilitzar colors de les flectes per indicar el puls."
+
+#: options.py:105
+msgid "Flat"
+msgstr "Pla"
+
+#: options.py:106
+msgid "All arrows are the same."
+msgstr "Totes les fletxes el mateix."
+
+#: options.py:107
+msgid "Different arrows have different colors."
+msgstr "Diferents fletxes tenen diferents colors."
+
+#: options.py:109
+msgid "Dark"
+msgstr "Fosc"
+
+#: options.py:110
+msgid "Don't display the top arrows."
+msgstr "No mostrar les fletxes de dalt."
+
+#: options.py:112
+msgid "Holds"
+msgstr "Aguantat:"
+
+#: options.py:113
+msgid "Allow hold ('freeze') arrows in songs."
+msgstr "Mostrar (congelar) les fletxes de les canons."
+
+#: options.py:115
+msgid "Scoring"
+msgstr "Sol "
+
+#: options.py:116
+msgid "The scoring algorithm."
+msgstr "Algorisme de puntuaci."
+
+#: options.py:118
+msgid "Grades"
+msgstr "Graus"
+
+#: options.py:119
+msgid "The grading algorithm."
+msgstr "L'algorisme de graus."
+
+#: options.py:121
+msgid "Combos"
+msgstr "Combo mx:"
+
+#: options.py:122
+msgid "How your combo increases."
+msgstr "Com incrementen els combos."
+
+#: options.py:124
+msgid "Judging Method"
+msgstr "Mtode de jutge"
+
+#: options.py:125
+msgid "How your steps are judged."
+msgstr "Com els passos sn jutjats."
+
+#: options.py:127
+msgid "Judging Windows"
+msgstr "Finestre de judici"
+
+#: options.py:128
+msgid "The margin of error for your steps."
+msgstr "El marge d'error dels passos."
+
+#: options.py:131
+msgid "Window is twice normal size."
+msgstr "Finestra s doble de mida normal."
+
+#: options.py:132
+msgid "Window is 9/5 normal size."
+msgstr "Finestra s 9/5 de mida normal."
+
+#: options.py:133
+msgid "Window is 8/5 normal size."
+msgstr "Finestra s 8/5 de mida normal."
+
+#: options.py:134
+msgid "Window is 7/5 normal size."
+msgstr "Finestra s 7/5 de mida normal."
+
+#: options.py:135
+msgid "Window is 6/5 normal size."
+msgstr "Finestra s 6/5 de mida normal."
+
+#: options.py:136
+msgid "Window is 4/5 normal size."
+msgstr "Finestra s 4/5 de mida normal."
+
+#: options.py:137
+msgid "Window is 3/5 normal size."
+msgstr "Finestra s 3/5 de mida normal."
+
+#: options.py:138
+msgid "Window is 2/5 normal size."
+msgstr "Finestra s 2/5 de mida normal."
+
+#: options.py:139
+msgid "Window is 1/5 normal size."
+msgstr "Finestra s 1/5 de mida normal."
+
+#: options.py:142
+msgid "Life"
+msgstr "Agrada"
+
+#: options.py:143
+msgid "Increase or decrease your amount of (non-battery) life."
+msgstr "Incrementar o decrementar la quantitat de (no bateria) vida."
+
+#: options.py:144
+msgid "Undead"
+msgstr "No Mort"
+
+#: options.py:144
+msgid "Life is 1/4 the usual amount."
+msgstr "Vida s 1/4 de la quantitat normal."
+
+#: options.py:145
+msgid "Very Low"
+msgstr "Molt baix"
+
+#: options.py:145
+msgid "Life is 1/2 the usual amount."
+msgstr "Vida s 1/2 de la quantitat normal."
+
+#: options.py:146
+msgid "Low"
+msgstr "Baix"
+
+#: options.py:146
+msgid "Life is 3/4 the usual amount."
+msgstr "Vida s 3/4 de la quantitat normal."
+
+#: options.py:148
+msgid "High"
+msgstr "Alt"
+
+#: options.py:148
+msgid "Life is 5/4 the usual amount."
+msgstr "Vida s 5/4 de la quantitat normal."
+
+#: options.py:149
+msgid "Very High"
+msgstr "Molt Alt"
+
+#: options.py:149
+msgid "Life is 3/2 the usual amount."
+msgstr "Vida s 3/2 de la quantitat normal."
+
+#: options.py:150
+msgid "Lazarus"
+msgstr "Lassarell?"
+
+#: options.py:150
+msgid "Life is 7/4 the usual amount."
+msgstr "Vida s 7/4 de la quantitat normal."
+
+#: options.py:152
+msgid "Lifebar"
+msgstr "Barra de vida"
+
+#: options.py:153
+msgid "The kind of lifebar used."
+msgstr "El tipus de barra de vida utilitzat."
+
+#: options.py:155
+msgid "Oni Lives"
+msgstr "Oni Vida"
+
+#: options.py:156
+msgid "The initial / maximum life in Battery mode."
+msgstr "La inicial/maxima vida a mode Bateria."
+
+#: options.py:158
+msgid "Secret Arrows"
+msgstr "Fletxes secretes"
+
+#: options.py:159
+msgid "Secret arrow display"
+msgstr "Fletxes secretes mostrades"
+
+#: options.py:160
+msgid "Disable secret arrows."
+msgstr "Desactivar fletxes secretes."
+
+#: options.py:161
+msgid "Invisible"
+msgstr "InvisibleCAT"
+
+#: options.py:161
+msgid "Enable but don't display them."
+msgstr "Activar per no ensenyar-les."
+
+#: options.py:162
+msgid "Faint"
+msgstr "Feble"
+
+#: options.py:162
+msgid "Show secret arrows faintly."
+msgstr "Mostrar feblement les fletxes secretes."
+
+#: options.py:164
+msgid "Battle Mode"
+msgstr "Mode batalla."
+
+#: options.py:165
+msgid "Arrows start in the center and float outwards."
+msgstr "Les fletxes comencen al centre i volen fora."
+
+#: options.py:176
+msgid "Up / Down: Select option"
+msgstr "Amunt / Avall: Canvieu la can selecionada"
+
+#: options.py:177
+msgid "Left / Right: Change value"
+msgstr "Esquerre / Dreta: Canvia la dificultat"
+
+#: options.py:178
+msgid "Start: Return to song selector"
+msgstr "Comena: torna a la selecci de can"
+
+#: options.py:179
+msgid "F11: Toggle fullscreen"
+msgstr "F11: Conmuta a pantalla completa"
+
+#: pad.py:12
+msgid "quit"
+msgstr "surt"
+
+#: pad.py:12
+msgid "up"
+msgstr "amunt"
+
+#: pad.py:12
+msgid "up-left"
+msgstr "Amunt-Esquerre"
+
+#: pad.py:12
+msgid "left"
+msgstr "Esquerra"
+
+#: pad.py:12
+msgid "down-left"
+msgstr "avall-esquerra"
+
+#: pad.py:13
+msgid "down"
+msgstr "avall"
+
+#: pad.py:13
+msgid "down-right"
+msgstr "avall-dreta"
+
+#: pad.py:13
+msgid "right"
+msgstr "Dreta"
+
+#: pad.py:13
+msgid "up-right"
+msgstr "Amunt-Dreta"
+
+#: pad.py:13
+msgid "center"
+msgstr "Centrar"
+
+#: pad.py:14
+msgid "start"
+msgstr "comena"
+
+#: pad.py:14
+msgid "select"
+msgstr "selecciona"
+
+#: pad.py:130 pad.py:186
+msgid "joystick(s) found."
+msgstr "joystick(s) trobat."
+
+#: pad.py:139
+#, python-format
+msgid "Joystick %d initialized: %d axes, %d buttons."
+msgstr "joystic %d inicialitzat: %d eixos %d botons."
+
+#: pad.py:156
+msgid "W: Unable to load input configuration file."
+msgstr "W: No es pot carregar el fitxer de configuraci d'entrada."
+
+#: pad.py:160
+msgid "Loaded input configuration."
+msgstr "Configuraci d'entrada carregada."
+
+#: pad.py:164
+msgid "EMSUSB2 found. Using preset EMSUSB2 config."
+msgstr "EMSUSB2 trobat. Utilitzant configuraci per omissi EMSUB2."
+
+#: pad.py:168
+#, python-format
+msgid "Initializing player 1 using js%d."
+msgstr "Inicialitzant jugador 1 utilitzant js%d."
+
+#: pad.py:174
+#, python-format
+msgid "Initializing player 2 using js%d."
+msgstr "Inicialitzant jugador 2 utilitzant js%d."
+
+#: pad.py:177
+msgid "No known joysticks found! If you want to use yours,"
+msgstr "Joystics coneguts no trobats! Si vols utilitzar el teu,"
+
+#: pad.py:178
+msgid "you'll have to map its button manually once to use it."
+msgstr "hauras de mapejar els buttons manualment per utilitzar-lo."
+
+#: pad.py:309
+#, python-format
+msgid "Press a key for %s (escape to cancel)"
+msgstr "Presiona una tecla per %s (ESC o cancela)"
+
+#: pad.py:312
+#, python-format
+msgid "Press a button for %s (escape to cancel)"
+msgstr "Presiona un bot per %s (ESC o cancel)"
+
+#: pad.py:336
+msgid "Player 1"
+msgstr "Jugador 1"
+
+#: pad.py:336
+msgid "Player 2"
+msgstr "Jugador 2"
+
+#: pad.py:337
+msgid "Keyboard"
+msgstr "Teclat"
+
+#: pad.py:337
+msgid "Joystick"
+msgstr "Joystic"
+
+#: player.py:96
+msgid "OK"
+msgstr "D'ACORD"
+
+#: player.py:97
+msgid "NG"
+msgstr "NG"
+
+#: player.py:142 player.py:143
+msgid "MARVELOUS"
+msgstr "MERAVELLS"
+
+#: player.py:145 player.py:146
+msgid "PERFECT"
+msgstr "PERFECTE"
+
+#: player.py:148 player.py:149
+msgid "GREAT"
+msgstr "FANTSTIC"
+
+#: player.py:151 player.py:152
+msgid "OKAY"
+msgstr "D'ACORD"
+
+#: player.py:154 player.py:155
+msgid "BOO"
+msgstr "BUU!"
+
+#: player.py:157 player.py:158
+msgid "MISS"
+msgstr "PASSAT"
+
+#: pydance.py:15
+#, python-format
+msgid "Usage: %s [options]"
+msgstr "s: %s [opcions]"
+
+#: pydance.py:16
+msgid " -h, --help         display this help text and exit"
+msgstr " -h, --help         mostra aquest text d'ajuda i surt"
+
+#: pydance.py:17
+msgid " -v, --version      display the version and exit"
+msgstr " -v, --version     motra la versi i surt"
+
+#: pydance.py:18
+msgid " -f, --filename     load and play a step file"
+msgstr " -f, --filename      carrega i executa un fitxer de dana "
+
+#: pydance.py:19
+msgid " -m, --mode         the mode to play the file in (default SINGLE)"
+msgstr "-m, --mode       el mode per jugar el fitxer (per omissi SINGLE)"
+
+#: pydance.py:20
+msgid " -d, --difficulty   the difficult to play the file (default BASIC)"
+msgstr ""
+" -d, --difficulty    la dificultat per jugar el fitxer (per omissi BASIC)"
+
+#: pydance.py:24
+#, python-format
+msgid "pydance %s by Joe Wreschnig, Brendan Becker, and others"
+msgstr "pydance %s per Joe Wreschning, Brendan Becker, i altres"
+
+#: pydance.py:62
+msgid "E: Can't get a 16 bit display! pydance doesn't work in 8 bit mode."
+msgstr ""
+"E: No es pot posar el display a 16 bits! pydance no funciona en mode 8 bits"
+
+#: pydance.py:68
+msgid "Entering debug (play-and-quit) mode."
+msgstr "Entrant en mode debug (jugar i sortir)."
+
+#: pydance.py:88
+#, python-format
+msgid "Found %d %s. Loading..."
+msgstr "Trobat %d %s. Carregant..."
+
+#: pydance.py:95 pydance.py:96 pydance.py:100
+msgid "E:"
+msgstr "E:"
+
+#: pydance.py:99
+msgid "E: Unknown error loading"
+msgstr "E: Error desconegut carregant"
+
+#: pydance.py:101
+msgid "E: Please contact the developers (pyddr-devel@icculus.org)."
+msgstr ""
+"E: Si us plau, contacteu amb els desenvolupadors (pyddr-devel@icculus.org)."
+
+#: pydance.py:120
+msgid "Psyco optimizing compiler found. Using psyco.full()."
+msgstr "Trobar l'optimitzador de compilador Psyco. Utilitzant psyco.full()."
+
+#: pydance.py:122
+msgid "W: Psyco optimizing compiler not found."
+msgstr ".W: Comiplador-optimitzador Psyco no trobar."
+
+#: pydance.py:131
+msgid "--help"
+msgstr "--help"
+
+#: pydance.py:132
+msgid "--version"
+msgstr "--version"
+
+#: pydance.py:133
+msgid "--filename"
+msgstr "--filename"
+
+#: pydance.py:134
+msgid "--mode"
+msgstr "--mode"
+
+#: pydance.py:135
+msgid "--difficulty"
+msgstr "--difficulty"
+
+#: pydance.py:142
+msgid "Searching for songs in"
+msgstr "Buscant canons a"
+
+#: pydance.py:145
+msgid "Searching for courses in"
+msgstr "Buscant cursos a"
+
+#: pydance.py:191
+msgid ""
+"You don't have any songs or step files. Check out http://icculus.org/pyddr/"
+"get.php#songs and download some free ones. If you already have some, make "
+"sure they're in "
+msgstr ""
+"No teniu cap cano o fitxers de dana. Comproveu http://icculus.org/pyddr/"
+"get.php#songs per baixar-ne alguns de lliures. Si ja en teniu algunes, "
+"assegureu-vos que les teniu a"
+
+#: pydance.py:196
+msgid ""
+"You don't have any songs. Check http://icculus.org/pyddr/get.php#songs ."
+msgstr "No teniu cap cano. Mireu a http://icculus.org/pyddr/get.php#songs ."
+
+#: scores.py:187
+msgid "pydance"
+msgstr "pydance"
+
+#: scores.py:187
+msgid "DDR 1st/2nd Mix"
+msgstr "DDR 1st/2nd Mix"
+
+#: scores.py:188
+msgid "DDR 3rd Mix"
+msgstr "DDR 3rd Mix"
+
+#: scores.py:188
+msgid "DDR 4th Mix"
+msgstr "DDR 4th Mix"
+
+#: scores.py:189
+msgid "DDR 5th Mix"
+msgstr "DDR 5th Mix"
+
+#: scores.py:189
+msgid "DDR 7th/8th"
+msgstr "DDR 7th/8th"
+
+#: scores.py:190
+msgid "DDR 8th Oni"
+msgstr "DDR 8th Oni"
+
+#: scores.py:190
+msgid "DDR 8th Nonstop"
+msgstr "DDR 8th Nonstop"
+
+#: scores.py:191
+msgid "EZ2 Dancer"
+msgstr "EZ2 Dancer"
+
+#: songselect.py:51
+msgid "Enter / Up Right: Open a folder or start a song"
+msgstr "Enter / Amunt dreta: Obriu una carpeta o comenceu una can"
+
+#: songselect.py:52
+msgid "Escape / Up Left: Closes  folder or exit"
+msgstr "Escape / Amunt esquerre: tanqueu una carpeta o surt"
+
+#: songselect.py:53
+msgid "Tab / Select: Go to a random song"
+msgstr "Tab / Select: Anar a una can aleatoria"
+
+#: songselect.py:54
+msgid "Start: Go to the options screen"
+msgstr "Start: anar a la pantalla d'opcions"
+
+#: songselect.py:149
+msgid "You don't have any songs for the game mode ("
+msgstr "No teniu cap cano al mode joc ("
+
+#: songselect.py:150
+msgid ") that you selected."
+msgstr ") que hgiu seleccionat"
+
+#: songselect.py:219
+msgid "None"
+msgstr "Cap"
+
+#: songselect.py:288
+msgid "You don't have any songs that are marked "
+msgstr "No tendiu cap can marcada"
+
+#: songselect.py:289
+msgid "\"valid\" for random selection."
+msgstr "\"valid\" com a selecci aleatoria"
+
+#: songselect.py:296
+msgid "You don't have any songs here that "
+msgstr "No teniu cap can aqu que"
+
+#: songselect.py:297
+msgid "are marked \"valid\" for random selection."
+msgstr "estigui marcada \"valid\" per selecci aleatoria"
+
+#: util.py:15
+msgid "BEGINNER"
+msgstr "PRINCIPANT"
+
+#: util.py:15
+msgid "EASY"
+msgstr "FCIL"
+
+#: util.py:15
+msgid "LIGHT"
+msgstr "LLUM"
+
+#: util.py:15
+msgid "BASIC"
+msgstr "BSIC"
+
+#: util.py:15
+msgid "PARA"
+msgstr "PARA"
+
+#: util.py:16
+msgid "ANOTHER"
+msgstr "ALTRE"
+
+#: util.py:16
+msgid "NORMAL"
+msgstr "NORMAL"
+
+#: util.py:16
+msgid "MEDIUM"
+msgstr "MITJ"
+
+#: util.py:16
+msgid "STANDARD"
+msgstr "ESTNDARD"
+
+#: util.py:17
+msgid "TRICK"
+msgstr "TRAMPA"
+
+#: util.py:17
+msgid "DOUBLE"
+msgstr "DOBLE"
+
+#: util.py:17
+msgid "HARD"
+msgstr "DUR"
+
+#: util.py:17
+msgid "MANIAC"
+msgstr "MANIATIC"
+
+#: util.py:17
+msgid "HEAVY"
+msgstr "PESAT"
+
+#: util.py:18
+msgid "HARDCORE"
+msgstr "COREHARD"
+
+#: util.py:18
+msgid "CHALLENGE"
+msgstr "REPTE"
+
+#: util.py:18
+msgid "ONI"
+msgstr "ONI"
+
+#: util.py:18
+msgid "SMANIAC"
+msgstr "S MANIATIC"
+
+#: util.py:19
+msgid "S-MANIAC"
+msgstr "S-MANIATIC"
+
+#: util.py:19
+msgid "CRAZY"
+msgstr "BOIG"
+
+#: util.py:19
+msgid "EXPERT"
+msgstr "EXPERT"
Index: po/Makefile
===================================================================
--- po/Makefile	(revision 0)
+++ po/Makefile	(revision 0)
@@ -0,0 +1,19 @@
+#Inspired from Powertop po/Makefile
+
+SRC=$(wildcard *.po)
+OBJ= $(SRC:.po=.mo)
+INST= $(SRC:.po=.inst)
+
+translations: $(OBJ)
+
+%.mo: %.po
+	-@msgfmt -o $@  $<
+
+clean:
+	rm -f *.mo *~
+
+install: $(OBJ) $(INST)
+
+%.inst: %.mo
+	mkdir -p $(DESTDIR)$(LOCALESDIR)/$*/LC_MESSAGES/
+	-cp -f $< $(DESTDIR)$(LOCALESDIR)/$*/LC_MESSAGES/pydance.mo
Index: endless.py
===================================================================
--- endless.py	(revision 1038)
+++ endless.py	(working copy)
@@ -13,14 +13,16 @@
 
 import ui
 
+from i18n import *
+
 ENDLESS_HELP = [
-  "Left: Make the songs that will be played easier",
-  "Right: Make the songs that will be played harder",
-  "Up: Select difficulty by name",
-  "Down: Select difficulty by rating",
-  "Enter / Up Right: Start playing songs until you fail",
-  "Escape / Up Left: Go back to the game selection screen",
-  "Start: Go to the options screen / F11: Toggle fullscreen",
+  _("Left: Make the songs that will be played easier"),
+  _("Right: Make the songs that will be played harder"),
+  _("Up: Select difficulty by name"),
+  _("Down: Select difficulty by rating"),
+  _("Enter / Up Right: Start playing songs until you fail"),
+  _("Escape / Up Left: Go back to the game selection screen"),
+  _("Start: Go to the options screen / F11: Toggle fullscreen"),
   ]
 
 def check_constraints(constraints, diff):
@@ -32,7 +34,7 @@
   def __init__(self, pid, constraint):
     pygame.sprite.Sprite.__init__(self)
     self._c = constraint
-    self._ptext = fontfx.shadow("Player %d" % (pid + 1), 60, colors.WHITE)
+    self._ptext = fontfx.shadow(_("Player %d") % (pid + 1), 60, colors.WHITE)
     self._pr = self._ptext.get_rect()
     self._centerx = 160 + 320 * pid
     self._oldval = None
@@ -41,11 +43,12 @@
   def update(self, time):
     if self._oldval != (self._c.kind, self._c.value):
       if self._c.kind == "name":
-        ctext = fontfx.shadow("Select by Difficulty", 48, colors.WHITE)
-        vtext = fontfx.shadow(self._c.value.capitalize(), 40, colors.WHITE)
+        ctext = fontfx.shadow(_("Select by Difficulty"), 48, colors.WHITE)
+	i18ndifficulty = _(self._c.value)
+	vtext = fontfx.shadow(i18ndifficulty.capitalize(), 40, colors.WHITE)
       elif self._c.kind == "number":
-        ctext = fontfx.shadow("Select by Rating", 48, colors.WHITE)
-        vtext = fontfx.shadow("Between %d and %d" % self._c.value, 40,
+        ctext = fontfx.shadow(_("Select by Rating"), 48, colors.WHITE)
+        vtext = fontfx.shadow(_("Between %d and %d") % self._c.value, 40,
                                  colors.WHITE)
       self.image = pygame.Surface([300, 400])
       cr = ctext.get_rect()
@@ -107,8 +110,8 @@
   def next(self):
     if len(self.songs) == 0:
       error.ErrorMessage(self.screen,
-                         "The difficulty settings you chose result " +
-                         "in no songs being available to play.")
+                         _("The difficulty settings you chose result ") +
+                         _("in no songs being available to play."))
       raise StopIteration
     elif len(self.working) == 0: self.working = self.songs[:]
     i = random.randint(0, len(self.working) - 1)
@@ -142,8 +145,8 @@
     diffs.sort(util.difficulty_sort)
 
     if len(diffs) == 0:
-      error.ErrorMessage(screen, "You need more songs to play Endless Mode. " +
-                         "Otherwise, it's just really boring.")
+      error.ErrorMessage(screen, _("You need more songs to play Endless Mode. ") +
+                         _("Otherwise, it's just really boring."))
       return
 
     mainconfig["autofail"] = 1
Index: scores.py
===================================================================
--- scores.py	(revision 1038)
+++ scores.py	(working copy)
@@ -18,6 +18,8 @@
 from listener import Listener
 from constants import *
 
+from i18n import *
+
 class AbstractScore(Listener, pygame.sprite.Sprite):
   def __init__(self, pid, text, game):
     pygame.sprite.Sprite.__init__(self)
@@ -37,7 +39,7 @@
     self.oldscore = -1 # Force a refresh
 
   def set_song(self, pid, bpm, difficulty, count, holds, feet):
-    self._set_text(difficulty)
+    self._set_text(_(difficulty))
 
   def update(self, curtime):
     if self.score != self.oldscore:
@@ -182,8 +184,8 @@
 scores = [PydanceScore, FirstScore, ThirdScore, FourthScore,
           FifthScore, ExtremeScore, ExtremeOniScore, ExtremeNonstopScore,
           EZ2DancerScore]
-score_opt = [(0, "pydance", ""), (1, "DDR 1st/2nd Mix", ""),
-             (2, "DDR 3rd Mix", ""), (3, "DDR 4th Mix", ""),
-             (4, "DDR 5th Mix", ""), (5, "DDR 7th/8th", ""),
-             (6, "DDR 8th Oni", ""), (7, "DDR 8th Nonstop", ""),
-             (8, "EZ2 Dancer", "")]
+score_opt = [(0, _("pydance"), ""), (1, _("DDR 1st/2nd Mix"), ""),
+             (2, _("DDR 3rd Mix"), ""), (3, _("DDR 4th Mix"), ""),
+             (4, _("DDR 5th Mix"), ""), (5, _("DDR 7th/8th"), ""),
+             (6, _("DDR 8th Oni"), ""), (7, _("DDR 8th Nonstop"), ""),
+             (8, _("EZ2 Dancer"), "")]
Index: courseselect.py
===================================================================
--- courseselect.py	(revision 1038)
+++ courseselect.py	(working copy)
@@ -18,6 +18,8 @@
 from courses import CRSFile
 from pygame.mixer import music
 
+from i18n import *
+
 NO_BANNER = os.path.join(image_path, "no-banner.png")
 
 SORTS = {
@@ -33,13 +35,13 @@
 NUM_SORTS = len(SORT_NAMES)
 
 CS_HELP = [
-  "Up / Down: Change song selection",
-  "Left / Right: Change difficulty setting",
-  "Enter / Up Right: Open a folder or start a course",
-  "Escape / Up Left: Close a folder or exit",
-  "Tab / Select: Go to a random course",
-  "Start: Switch to Options screen",
-  "F11: Toggle fullscreen - S: Change the sort mode",
+  _("Up / Down: Change song selection"),
+  _("Left / Right: Change difficulty setting"),
+  _("Enter / Up Right: Open a folder or start a course"),
+  _("Escape / Up Left: Close a folder or exit"),
+  _("Tab / Select: Go to a random course"),
+  _("Start: Switch to Options screen"),
+  _("F11: Toggle fullscreen - S: Change the sort mode"),
   ]
 
 class CourseDisplay(object):
@@ -65,42 +67,42 @@
     i = 1
     for name, diff, mods in self.course.songs:
       if "*" in name: name, subtitle = "??????????", ""
-      elif name[0] == "BEST":
+      elif name[0] == _("BEST"):
         song = recordkeys.get(records.best(name[1], diff, game))
         if song:
-          subtitle = (song.info["subtitle"] or "") + (" (Best #%d)" % name[1])
+          subtitle = (song.info["subtitle"] or "") + (_(" (Best #%d)") % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Best Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Best Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "WORST":
+      elif name[0] == _("WORST"):
         song = recordkeys.get(records.worst(name[1], diff, game))
         if song:
           subtitle = (song.info["subtitle"] or "") + (" (Worst #%d)" % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Worst Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Worst Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "LIKES":
+      elif name[0] == _("LIKES"):
         song = recordkeys.get(records.like(name[1], diff, game))
         if song:
           subtitle = (song.info["subtitle"] or "") + (" (Likes #%d)" % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Likes Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Likes Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "DISLIKES":
+      elif name[0] == _("DISLIKES"):
         song = recordkeys.get(records.dislike(name[1], diff, game))
         if song:
           subtitle = ((song.info["subtitle"] or "") +
                       (" (Dislikes #%d)" % name[1]))
           name = song.info["title"]
         else:
-          name = "Player's Dislikes Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Dislikes Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
       else: name, subtitle = util.find_subtitle(name.split("/")[-1])
 
@@ -172,6 +174,7 @@
   def render(self):
     if self.banner: return
 
+    print "NAME:",self.name 
     name = self.name.encode("ascii", "ignore")
     for path in [rc_path, pydance_path]:
       filename = os.path.join(path, "banners", self._type, name+".png")
@@ -209,7 +212,7 @@
       self._create_folder_list()
     else:
       self._folders = None
-      self._base_text = "All Courses"
+      self._base_text = _("All Courses")
       self._courses.sort(SORTS[SORT_NAMES[mainconfig["sortmode"] % NUM_SORTS]])
       self._list.set_items([s.name for s in self._courses])
 
@@ -364,7 +367,7 @@
     self._courses = new_courses
     self._list.set_items([s.fullname for s in self._courses])
     
-    self._base_text = "Sort by %s" % sort.capitalize()
+    self._base_text = _("Sort by %s") % sort.capitalize()
     
   def _create_course_list(self, folder):
     sort = SORT_NAMES[mainconfig["sortmode"] % NUM_SORTS]
Index: interface.py
===================================================================
--- interface.py	(revision 1038)
+++ interface.py	(working copy)
@@ -9,6 +9,8 @@
 
 from constants import *
 
+from i18n import *
+
 # Make an outlined box. The size is given without the 4 pixel border.
 # This usually gets alphaed before stuff gets put in it.
 def make_box(color = [111, 255, 148], size = [130, 40]):
@@ -346,7 +348,8 @@
     f = pygame.font.Font(None, 24)
     self.image = make_box(color)
 
-    t1 = fontfx.shadow(diff, f, [255, 255, 255])
+    #diff has to be translated: _( ) (BEGINNER, etc.)
+    t1 = fontfx.shadow(_(diff), f, [255, 255, 255])
     r1 = t1.get_rect()
     r1.center = [self.image.get_width()/2, 14]
 
Index: gameselect.py
===================================================================
--- gameselect.py	(revision 1038)
+++ gameselect.py	(working copy)
@@ -7,19 +7,21 @@
 import ui
 import endless, courseselect, songselect
 
+from i18n import *
+
 GS_HELP = [
-  "Up / Down: Change game, mode, or interface",
-  "Enter / Up Right: Advance your choice",
-  "Escape / Up Left: Back up or exit",
-  "F11: Toggles fullscreen",
-  "Enjoy pydance %s!" % VERSION,
+  _("Up / Down: Change game, mode, or interface"),
+  _("Enter / Up Right: Advance your choice"),
+  _("Escape / Up Left: Back up or exit"),
+  _("F11: Toggles fullscreen"),
+  _("Enjoy pydance %s!") % VERSION,
   ]
 
 # The game, type, and interfaces available on the screen.
-GAMES = ["4 panel", "5 panel", "6 panel", "8 panel", "9 panel",
-         "Parapara", "DMX", "EZ2", "EZ2 Real", "3 panel"]
-TYPES = ["Single", "Versus", "Double", "Couple"]
-SS = ["Normal", "Nonstop", "Endless"]
+GAMES = [_("4 panel"), _("5 panel"), _("6 panel"), _("8 panel"), _("9 panel"),
+         _("Parapara"), _("DMX"), _("EZ2"), _("EZ2 Real"), _("3 panel")]
+TYPES = [_("Single"), _("Versus"), _("Double"), _("Couple")]
+SS = [_("Normal"), _("Nonstop"), _("Endless")]
 
 VALUES = [GAMES, TYPES, SS]
 
@@ -54,108 +56,108 @@
 # Filenames for each mode, or functions to call with the previous image
 # to construct the new image.
 IMAGES = {
-    "3 panel": "select-3p.png",
-    "4 panel": "select-4p.png",
-    "5 panel": "select-5p.png",
-    "6 panel": "select-6p.png",
-    "8 panel": "select-8p.png",
-    "9 panel": "select-9p.png",
-    "Parapara": "select-para.png",
-    "EZ2 Real": "select-ez2real.png",
-    "EZ2": "select-ez2.png",
-    "DMX": "select-dmx.png",
-    "Single": (lambda x: x),
-    "Versus": make_versus,
-    "Double": make_double,
-    "Couple": make_couple,
-    "Normal": "select-normal.png",
-    "Nonstop": "select-nonstop.png",
-    "Endless": "select-endless.png",
+    _("3 panel"): "select-3p.png",
+    _("4 panel"): "select-4p.png",
+    _("5 panel"): "select-5p.png",
+    _("6 panel"): "select-6p.png",
+    _("8 panel"): "select-8p.png",
+    _("9 panel"): "select-9p.png",
+    _("Parapara"): "select-para.png",
+    _("EZ2 Real"): "select-ez2real.png",
+    _("EZ2"): "select-ez2.png",
+    _("DMX"): "select-dmx.png",
+    _("Single"): (lambda x: x),
+    _("Versus"): make_versus,
+    _("Double"): make_double,
+    _("Couple"): make_couple,
+    _("Normal"): "select-normal.png",
+    _("Nonstop"): "select-nonstop.png",
+    _("Endless"): "select-endless.png",
     }
 
 # Constructors for the different interfaces.
 SELECTORS = {
-  "Endless": endless.Endless,
-  "Nonstop": courseselect.CourseSelector,
-  "Normal": songselect.SongSelect,
+  _("Endless"): endless.Endless,
+  _("Nonstop"): courseselect.CourseSelector,
+  _("Normal"): songselect.SongSelect,
   }
 
 # Map the game and type onto an internal name for SongItem.difficulty.
 MODES = {
-  ("4 panel", "Single"): "SINGLE",
-  ("4 panel", "Versus"): "VERSUS",
-  ("4 panel", "Couple"): "COUPLE",
-  ("4 panel", "Double"): "DOUBLE",
+  (_("4 panel"), _("Single")): "SINGLE",
+  (_("4 panel"), _("Versus")): "VERSUS",
+  (_("4 panel"), _("Couple")): "COUPLE",
+  (_("4 panel"), _("Double")): "DOUBLE",
 
-  ("3 panel", "Single"): "3PANEL",
-  ("3 panel", "Versus"): "3VERSUS",
-  ("3 panel", "Couple"): "3COUPLE",
-  ("3 panel", "Double"): "3DOUBLE",
+  (_("3 panel"), _("Single")): "3PANEL",
+  (_("3 panel"), _("Versus")): "3VERSUS",
+  (_("3 panel"), _("Couple")): "3COUPLE",
+  (_("3 panel"), _("Double")): "3DOUBLE",
 
-  ("5 panel", "Single"): "5PANEL",
-  ("5 panel", "Versus"): "5VERSUS",
-  ("5 panel", "Couple"): "5COUPLE",
-  ("5 panel", "Double"): "5DOUBLE",
+  (_("5 panel"), _("Single")): "5PANEL",
+  (_("5 panel"), _("Versus")): "5VERSUS",
+  (_("5 panel"), _("Couple")): "5COUPLE",
+  (_("5 panel"), _("Double")): "5DOUBLE",
 
-  ("6 panel", "Single"): "6PANEL",
-  ("6 panel", "Versus"): "6VERSUS",
-  ("6 panel", "Couple"): "6COUPLE",
-  ("6 panel", "Double"): "6DOUBLE",
+  (_("6 panel"), _("Single")): "6PANEL",
+  (_("6 panel"), _("Versus")): "6VERSUS",
+  (_("6 panel"), _("Couple")): "6COUPLE",
+  (_("6 panel"), _("Double")): "6DOUBLE",
 
-  ("8 panel", "Single"): "8PANEL",
-  ("8 panel", "Versus"): "8VERSUS",
-  ("8 panel", "Couple"): "8COUPLE",
-  ("8 panel", "Double"): "8DOUBLE",
+  (_("8 panel"), _("Single")): "8PANEL",
+  (_("8 panel"), _("Versus")): "8VERSUS",
+  (_("8 panel"), _("Couple")): "8COUPLE",
+  (_("8 panel"), _("Double")): "8DOUBLE",
 
-  ("9 panel", "Single"): "9PANEL",
-  ("9 panel", "Versus"): "9VERSUS",
-  ("9 panel", "Couple"): "9COUPLE",
-  ("9 panel", "Double"): "9DOUBLE",
+  (_("9 panel"), _("Single")): "9PANEL",
+  (_("9 panel"), _("Versus")): "9VERSUS",
+  (_("9 panel"), _("Couple")): "9COUPLE",
+  (_("9 panel"), _("Double")): "9DOUBLE",
 
-  ("Parapara", "Single"): "PARAPARA",
-  ("Parapara", "Versus"): "PARAVERSUS",
-  ("Parapara", "Couple"): "PARACOUPLE",
-  ("Parapara", "Double"): "PARADOUBLE",
+  (_("Parapara"), _("Single")): "PARAPARA",
+  (_("Parapara"), _("Versus")): "PARAVERSUS",
+  (_("Parapara"), _("Couple")): "PARACOUPLE",
+  (_("Parapara"), _("Double")): "PARADOUBLE",
 
-  ("DMX", "Single"): "DMX",
-  ("DMX", "Versus"): "DMXVERSUS",
-  ("DMX", "Couple"): "DMXCOUPLE",
-  ("DMX", "Double"): "DMXDOUBLE",
+  (_("DMX"), _("Single")): "DMX",
+  (_("DMX"), _("Versus")): "DMXVERSUS",
+  (_("DMX"), _("Couple")): "DMXCOUPLE",
+  (_("DMX"), _("Double")): "DMXDOUBLE",
 
-  ("EZ2", "Single"): "EZ2SINGLE",
-  ("EZ2", "Versus"): "EZ2VERSUS",
-  ("EZ2", "Couple"): "EZ2COUPLE",
-  ("EZ2", "Double"): "EZ2DOUBLE",
+  (_("EZ2"), _("Single")): "EZ2SINGLE",
+  (_("EZ2"), _("Versus")): "EZ2VERSUS",
+  (_("EZ2"), _("Couple")): "EZ2COUPLE",
+  (_("EZ2"), _("Double")): "EZ2DOUBLE",
 
-  ("EZ2 Real", "Single"): "EZ2REAL",
-  ("EZ2 Real", "Versus"): "REALVERSUS",
-  ("EZ2 Real", "Couple"): "REALCOUPLE",
-  ("EZ2 Real", "Double"): "REALDOUBLE",
+  (_("EZ2 Real"), _("Single")): "EZ2REAL",
+  (_("EZ2 Real"), _("Versus")): "REALVERSUS",
+  (_("EZ2 Real"), _("Couple")): "REALCOUPLE",
+  (_("EZ2 Real"), _("Double")): "REALDOUBLE",
 }
 
 DESCRIPTIONS = {
-  "4 panel": ("The standard up, down, left and right arrows " +
-              "like Dance Dance Revolution)"),
-  "3 panel": "Practice using up left and up right with easier steps.",
-  "5 panel": "Diagonal arrows and the center (like Pump It Up)",
-  "6 panel": "Four panel plus the upper diagonal arrows (like DDR Solo)",
-  "8 panel": "Everything but the center (like Technomotion)",
-  "9 panel": "Everything! (like Pop'n'Stage)",
-  "Parapara": "Wave your arms (or feet) around",
-  "DMX": ("Crazy kung-fu action (like Dance ManiaX / Freaks). " +
-          "Use left, up left, up right, and right."),
+  _("4 panel"): (_("The standard up, down, left and right arrows ") +
+              _("like Dance Dance Revolution)")),
+  _("3 panel"): _("Practice using up left and up right with easier steps."),
+  _("5 panel"): _("Diagonal arrows and the center (like Pump It Up)"),
+  _("6 panel"): _("Four panel plus the upper diagonal arrows (like DDR Solo)"),
+  _("8 panel"): _("Everything but the center (like Technomotion)"),
+  _("9 panel"): _("Everything! (like Pop'n'Stage)"),
+  _("Parapara"): _("Wave your arms (or feet) around"),
+  _("DMX"): (_("Crazy kung-fu action (like Dance ManiaX / Freaks). ") +
+          _("Use left, up left, up right, and right.")),
 
-  "EZ2": "Three panels, two sensors, using left and right.",
-  "EZ2 Real": "Three panels and four sensors.",
+  _("EZ2"): _("Three panels, two sensors, using left and right."),
+  _("EZ2 Real"): _("Three panels and four sensors."),
 
-  "Single": "Play by yourself.",
-  "Versus": "Challenge an opponent to the same steps.",
-  "Couple": "Two people dance different steps to the same song.",
-  "Double": "Try playing on both sides at once.",
+  _("Single"): _("Play by yourself."),
+  _("Versus"): _("Challenge an opponent to the same steps."),
+  _("Couple"): _("Two people dance different steps to the same song."),
+  _("Double"): _("Try playing on both sides at once."),
 
-  "Normal": "Play one song at a time.",
-  "Endless": "Keep dancing until you fail.",
-  "Nonstop": "Play several songs in a row.",
+  _("Normal"): _("Play one song at a time."),
+  _("Endless"): _("Keep dancing until you fail."),
+  _("Nonstop"): _("Play several songs in a row."),
   }
 
 class MainWindow(InterfaceWindow):
@@ -165,7 +167,7 @@
     self._courses = courses
     self._indicator_y = [152, 322, 414]
     # Displayed in the upper right.
-    self._message = ["Select a Game", "Select a Mode", "Select Type"]
+    self._message = [_("Select a Game"), _("Select a Mode"), _("Select Type")]
 
     font = Font(None, 26)
 
@@ -185,8 +187,8 @@
     # Description of the currently selected object.
     self._description = WrapTextDisplay(30, 360, [25, 396])
     self._title.set_text(self._message[0])
-    self._selected.set_text("4 panel")
-    self._description.set_text(DESCRIPTIONS["4 panel"])
+    self._selected.set_text(_("4 panel"))
+    self._description.set_text(DESCRIPTIONS[_("4 panel")])
     self._sprites.add([self._title, self._selected, self._description])
     self._indicator = ActiveIndicator([405, 152], width = 230)
     self._sprites.add(self._indicator)
@@ -194,7 +196,7 @@
                                Font(None, 22), [206, 20]))
     self._sprites.add(self._lists)
     # The image displayed on the main part of the screen.
-    self._image = FlipImageDisplay(IMAGES.get("4 panel"), [200, 200])
+    self._image = FlipImageDisplay(IMAGES.get(_("4 panel")), [200, 200])
     self._sprites.add(self._image)
 
     self._screen.blit(self._bg, [0, 0])
Index: dance.py
===================================================================
--- dance.py	(revision 1038)
+++ dance.py	(working copy)
@@ -23,6 +23,7 @@
 import records
 import ui
 import options
+import locale
 
 import os
 
@@ -139,13 +140,32 @@
 class ReadyGoSprite(pygame.sprite.Sprite):
   def __init__(self, time):
     pygame.sprite.Sprite.__init__(self)
-    ready = os.path.join(pydance_path, "images", "ready.png")
-    go = os.path.join(pydance_path, "images", "go.png")
+    ready = os.path.join(pydance_path, "images", "ready")
+    go = os.path.join(pydance_path, "images", "go")
     self._time = time
-    self._ready = pygame.image.load(ready).convert()
+
+    curr_locale = locale.getdefaultlocale()[0]
+
+    try:
+       ready_loc = ready+"_"+curr_locale+".png"
+       self._ready = pygame.image.load(ready_loc).convert()
+       ready = ready_loc
+    except:
+       ready = ready+".png"
+       self._ready = pygame.image.load(ready).convert()
+
     self._ready.set_colorkey(self._ready.get_at([0, 0]), RLEACCEL)
-    self._go = pygame.image.load(go).convert()
+
+    try:
+       go_loc = go+"_"+curr_locale+".png"
+       self._go = pygame.image.load(go_loc).convert()
+       go = go_loc
+    except:
+       go = go+".png"
+       self._go = pygame.image.load(go).convert()
+
     self._go.set_colorkey(self._go.get_at([0, 0]), RLEACCEL)
+
     self._pick_image(min(0, time))
 
   def update(self, cur_time):
@@ -198,9 +218,9 @@
       self._player_widgets += self.player_widgets(pid)
       self._player_opts += self.player_opts(pid)
 
-    self._other_widgets=[TextDisplay(50, [400, 50], [15, 35], "Next Song"),
-                         TextDisplay(30, [263, 37], [15, 450], "Confirm: Begin   Cancel: Stop"),
-                         TextDisplay(30, [263, 37], [380, 450], "Start: Change Options")]
+    self._other_widgets=[TextDisplay(50, [400, 50], [15, 35], _("Next Song")),
+                         TextDisplay(30, [263, 37], [15, 450], _("Confirm: Begin   Cancel: Stop")),
+                         TextDisplay(30, [263, 37], [380, 450], _("Start: Change Options"))]
     
     self._sprites.add([self._banner, self._countdown] +
                       self._player_widgets + self._player_opts +
@@ -237,7 +257,7 @@
 
   def player_widgets(self, pid):
     v_top = 11 + pid * 210
-    pname = WrapTextDisplay(50, 248, [380, v_top], "Player %d" % (pid+1,), centered=True)
+    pname = WrapTextDisplay(50, 248, [380, v_top], _("Player %d") % (pid+1,), centered=True)
     d=DifficultyBox([504, v_top+65])
     d.set(self.diffs[pid], DIFF_COLORS.get(self.diffs[pid], [127, 127, 127]),
           self.song.difficulty[self.playmode][self.diffs[pid]], "")
@@ -260,7 +280,7 @@
         summary.append(options.OPTIONS[opt][3][i_choice][1])
 
     if len(summary) == 0:
-      summary = "Default Settings"
+      summary = _("Default Settings")
     else:
       summary = ", ".join(summary)
       
@@ -291,7 +311,7 @@
   for songfn, diff in playlist:
     try: current_song = fileparsers.SongItem(songfn)
     except None:
-      error.ErrorMessage(screen, "There was an error loading " +
+      error.ErrorMessage(screen, _("There was an error loading ") +
                          os.path.split(songfn)[1])
       first = True
       continue
@@ -310,7 +330,7 @@
     for pid, player in enumerate(players):
       player.set_song(current_song, diff[pid], songdata.lyricdisplay)
 
-    print "Playing", songfn
+    print _("Playing"), songfn
     print songdata.title.encode("ascii", "replace"), "by",
     print songdata.artist.encode("ascii", "replace")
 
@@ -357,7 +377,7 @@
   if ready_go:
     ready_go_time = min(100, *[plr.ready for plr in players])
     tgroup.add(ReadyGoSprite(ready_go_time))
-
+  
   if mainconfig['showbackground'] > 0:
     if backmovie is None:
       bgkludge = pygame.image.load(song.background).convert()
@@ -407,8 +427,8 @@
   song.init()
 
   if song.crapout != 0:
-    error.ErrorMessage(screen, "The audio file for this song " +
-                       song.filename + " could not be found.")
+    error.ErrorMessage(screen, _("The audio file for this song ") +
+                       song.filename + _(" could not be found."))
     return False # The player didn't fail.
 
   if mainconfig['assist']: music.set_volume(0.6)
@@ -494,7 +514,7 @@
 
     if screenshot:
       fn = os.path.join(rc_path, "screenshot.bmp")
-      print "Saving a screenshot to", fn
+      print _("Saving a screenshot to"), fn
       pygame.image.save(screen, fn)
       screenshot = False
 
@@ -508,5 +528,5 @@
       songtext.zout()
       grptext.zout()
 
-  if fpstext: print "Average FPS for this song was %d." % fpstext.fps()
+  if fpstext: print _("Average FPS for this song was %d.") % fpstext.fps()
   return songFailed
Index: fileparsers.py
===================================================================
--- fileparsers.py	(revision 1038)
+++ fileparsers.py	(working copy)
@@ -785,11 +785,11 @@
              ("song.wav", KSFFile))
 
   defaults = { "valid": 1,
-               "mix": "No Mix",
-               "title": "Untitled",
+               "mix": _("No Mix"),
+               "title": _("Untitled"),
                "subtitle": "",
-               "artist": "Unknown",
-               "author": "Unknown",
+               "artist": _("Unknown"),
+               "author": _("Unknown"),
                "endat": 0.0,
                "preview": (45.0, 10.0),
                "startat": 0.0,
@@ -803,19 +803,19 @@
         song = pair[1](filename, need_steps)
         break
     if song == None:
-      raise RuntimeError(filename + " is an unsupported format.")
+      raise RuntimeError(filename + _(" is an unsupported format."))
     self.info = song.info
 
     # Sanity checks
     for k in ["bpm", "filename"]:
       if k not in self.info:
-        raise RuntimeError(filename + " is missing: " + k)
+        raise RuntimeError(filename + _(" is missing: ") + k)
 
     for k in ["subtitle", "title", "artist", "author", "mix"]:
       try:
         if k in self.info: self.info[k] = self.info[k].decode("utf-8")
       except UnicodeError:
-        print "W: Non-Unicode key in %s: %s" % (filename, k)
+        print _("W: Non-Unicode key in %s: %s") % (filename, k)
         self.info[k] = self.info[k].decode("ascii", "ignore")
 
     # Default values
Index: i18n.py
===================================================================
--- i18n.py	(revision 0)
+++ i18n.py	(revision 0)
@@ -0,0 +1,4 @@
+import gettext
+
+gettext.install('pydance','/usr/share/locale')
+
Index: gradescreen.py
===================================================================
--- gradescreen.py	(revision 1038)
+++ gradescreen.py	(working copy)
@@ -10,6 +10,8 @@
 from interface import *
 from constants import *
 
+from i18n import *
+
 # Fade in a 246x80 (not a typo!) graphic in the center of the screen.
 class BannerFadeIn(pygame.sprite.Sprite):
   def __init__(self, image, center):
@@ -37,7 +39,7 @@
         elif self._i > 250: self._idir = -4
         self._i += self._idir
         c = [self._i, 192, 192]
-        txt = fontfx.shadow("Press Escape/Confirm/Start", 24, c)
+        txt = fontfx.shadow(_("Press Escape/Confirm/Start"), 24, c)
         txt_r = txt.get_rect()
         txt_r.center = [123, 70]
         self.image.blit(txt, txt_r)
@@ -204,10 +206,10 @@
       ratings = (p.stats["V"], p.stats["P"], p.stats["G"],
                  p.stats["O"], p.stats["B"], p.stats["M"],
                  p.stats.good_holds, p.stats.hold_count)
-      print "GRADE: %s (%s) - total steps: %d; best combo: %d" % steps
-      print "V: %d P: %d G: %d O: %d B: %d M: %d - %d/%d holds" % ratings
+      print _("GRADE: %s (%s) - total steps: %d; best combo: %d") % steps
+      print _("V: %d P: %d G: %d O: %d B: %d M: %d - %d/%d holds") % ratings
       try:
-        print "Average off: %0.3f, standard deviation %0.2f" % p.stats.times()
+        print _("Average off: %0.3f, standard deviation %0.2f") % p.stats.times()
       except: pass # Python 2.2
       print
 
@@ -227,21 +229,21 @@
     s = [180, 34]
     # FIXME: There is probably a shorter way to do this.
     self._sprites.add([
-      StatSprite([200, 10], "MARVEL.:", plr.stats["V"], s, 0),
-      StatSprite([200, 39], "PERFECT:", plr.stats["P"], s, 333),
-      StatSprite([200, 68], "GREAT:", plr.stats["G"], s, 666),
-      StatSprite([200, 97], "OKAY:", plr.stats["O"], s, 1000),
-      StatSprite([200, 126], "BOO:", plr.stats["B"], s, 1333),
-      StatSprite([200, 155], "MISS:", plr.stats["M"], s, 1333),
-      StatSprite([400, 10], "Score:", int(plr.score.score), s, 666),
-      HoldStatSprite([400, 39], "Holds:", plr.stats.good_holds,
+      StatSprite([200, 10], _("MARVEL.:"), plr.stats["V"], s, 0),
+      StatSprite([200, 39], _("PERFECT:"), plr.stats["P"], s, 333),
+      StatSprite([200, 68], _("GREAT:"), plr.stats["G"], s, 666),
+      StatSprite([200, 97], _("OKAY:"), plr.stats["O"], s, 1000),
+      StatSprite([200, 126], _("BOO:"), plr.stats["B"], s, 1333),
+      StatSprite([200, 155], _("MISS:"), plr.stats["M"], s, 1333),
+      StatSprite([400, 10], _("Score:"), int(plr.score.score), s, 666),
+      HoldStatSprite([400, 39], _("Holds:"), plr.stats.good_holds,
                      plr.stats.hold_count, s, 1000),
-      StatSprite([400, 68], "Max Combo:", plr.stats.maxcombo, s, 1333),
-      StatSprite([400, 97], "Early:", plr.stats.early, s, 1666),
-      StatSprite([400, 126], "Late:", plr.stats.late, s, 2000),
-      StatSprite([400, 155], "TOTAL:", plr.stats.arrow_count, s, 2333)
+      StatSprite([400, 68], _("Max Combo:"), plr.stats.maxcombo, s, 1333),
+      StatSprite([400, 97], _("Early:"), plr.stats.early, s, 1666),
+      StatSprite([400, 126], _("Late:"), plr.stats.late, s, 2000),
+      StatSprite([400, 155], _("TOTAL:"), plr.stats.arrow_count, s, 2333)
       ])
-    plr.announcer.say("rating-" + p.grade.grade(p.failed).lower())
+    plr.announcer.say(_("rating-") + p.grade.grade(p.failed).lower())
     self._sprites.add(GradeSprite([98, 183], plr.grade.grade(plr.failed)))
     self._sprites.add(GrooveGaugeSprite([10, 22], [176, 100],
                                         plr.lifebar.record))
@@ -249,19 +251,19 @@
     if len(self.players) == 2:
       plr = self.players[1]
       self._sprites.add([
-        StatSprite([15, 290], "MARVEL.:", plr.stats["V"], s, 0),
-        StatSprite([15, 319], "PERFECT:", plr.stats["P"], s, 333),
-        StatSprite([15, 348], "GREAT:", plr.stats["G"], s, 666),
-        StatSprite([15, 377], "OKAY:", plr.stats["O"], s, 1000),
-        StatSprite([15, 406], "BOO:", plr.stats["B"], s, 1333),
-        StatSprite([15, 435], "MISS:", plr.stats["M"], s, 1666),
-        StatSprite([215, 290], "Score:", int(plr.score.score), s, 666),
-        HoldStatSprite([215, 319], "Holds:", plr.stats.good_holds,
+        StatSprite([15, 290], _("MARVEL.:"), plr.stats["V"], s, 0),
+        StatSprite([15, 319], _("PERFECT:"), plr.stats["P"], s, 333),
+        StatSprite([15, 348], _("GREAT:"), plr.stats["G"], s, 666),
+        StatSprite([15, 377], _("OKAY:"), plr.stats["O"], s, 1000),
+        StatSprite([15, 406], _("BOO:"), plr.stats["B"], s, 1333),
+        StatSprite([15, 435], _("MISS:"), plr.stats["M"], s, 1666),
+        StatSprite([215, 290], _("Score:"), int(plr.score.score), s, 666),
+        HoldStatSprite([215, 319], _("Holds:"), plr.stats.good_holds,
                    plr.stats.hold_count, s, 1000),
-        StatSprite([215, 348], "Max Combo:", plr.stats.maxcombo, s, 1333),
-        StatSprite([215, 377], "Early:", plr.stats.early, s, 1666),
-        StatSprite([215, 406], "Late:", plr.stats.late, s, 2000),
-        StatSprite([215, 435], "TOTAL:", plr.stats.arrow_count, s, 2333),
+        StatSprite([215, 348], _("Max Combo:"), plr.stats.maxcombo, s, 1333),
+        StatSprite([215, 377], _("Early:"), plr.stats.early, s, 1666),
+        StatSprite([215, 406], _("Late:"), plr.stats.late, s, 2000),
+        StatSprite([215, 435], _("TOTAL:"), plr.stats.arrow_count, s, 2333),
         ])
       self._sprites.add(GradeSprite([541, 294], plr.grade.grade(plr.failed)))
       self._sprites.add(GrooveGaugeSprite([453, 370], [176, 100],
